<?php

use common\auth\Identity;
use yii\caching\FileCache;
use yii\filters\Cors;
use yii\log\FileTarget;
use yii\rest\UrlRule;
use yii\web\JsonParser;
use yii\web\Response;

$params = array_merge(
    require __DIR__ . '/../../common/config/params.php',
    require __DIR__ . '/../../common/config/params-local.php',
    require __DIR__ . '/main-local.php',
    require __DIR__ . '/params-local.php'
);

return [
    'id' => 'app-api',
    'language' => 'ru_RU',
    'basePath' => dirname(__DIR__),
    'bootstrap' => [
        'log',
        [
            'class' => 'yii\filters\ContentNegotiator',
            'formatParam' => '_format',
            'formats' => [
                'application/json' => Response::FORMAT_JSON,
                //'application/xml' => Response::FORMAT_XML,
            ],
        ],
    ],
    'controllerNamespace' => 'api\controllers',
    'container' => [
        'definitions' => [// возможность получать списки без постраничной навигации (?per-page=0)
            'yii\data\Pagination' => ['pageSizeLimit' => [0, 200]],
        ],
    ],
    'modules' => [
        'v1' => [
            'class' => 'api\modules\v1\Module',
        ],
    ],
    'components' => [
        'request' => [
            'enableCookieValidation' => false,
           // 'cookieValidationKey' => 'JHKLldnsoLdsdlVCzfuR9jxrfk8Fz',
            'parsers' => [
                'application/json' => JsonParser::class,
            ],
            'enableCsrfValidation' => false,
        ],
        'response' => [
            'class' => Response::class,
            'format' => Response::FORMAT_JSON,
            'formatters' => [
                'json' => [
                    'class' => 'yii\web\JsonResponseFormatter',
                    'prettyPrint' => YII_DEBUG,
                    'encodeOptions' => JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE,
                ],
            ],
        ],
        'session' => [
            'useCookies' => false,
        ],
        'user' => [
            'identityClass' => Identity::class,
            'enableAutoLogin' => false,
            'enableSession' => false,
        ],
        'log' => [
            'traceLevel' => YII_DEBUG ? 3 : 0,
            'targets' => [
                [
                    'class' => FileTarget::class,
                    'levels' => ['error', 'warning'],
                    'except' => ['api\controllers\v1\*'],
                    'exportInterval' => 1,
                ],
                [
                    'class' => FileTarget::class,
                    'levels' => ['error', 'warning'],
                    'categories' => ['api\controllers\v1\*'],
                    'logVars' => ['_GET', '_POST'],
                    'logFile' => '@runtime/logs/controllers_v1.log',
                    'exportInterval' => 1,
                ],
            ],
            'flushInterval' => 1,
        ],
        'urlManager' => [
            'enablePrettyUrl' => true,
            'enableStrictParsing' => true,
            'showScriptName' => false,
            'rules' => [
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/site',
                    'extraPatterns' => [
                        'GET version' => 'version',
                    ],
                    'pluralize' => false,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/project',
                    //'prefix' => 'v1/projects/<project_id:\d+>',
                    'extraPatterns' => [
                        'GET <project_id:\d+>/images' => 'images',
                        'GET image/<image_id:\d+>' => 'image',
                        'GET image/<image_id:\d+>/figures' => 'figures',
                        'GET image/<image_id:\d+>/axes' => 'axes',
                        'GET <project_id:\d+>/estimates' => 'estimates',
                    ],
                    'pluralize' => false,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/unit-measure',
                    'pluralize' => true,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/work-list',
                    'extraPatterns' => [
                        'GET works' => 'works',
                    ],
                    'pluralize' => true,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/consumption-rate',
                    'extraPatterns' => [
                        'GET rates/<work_id:\d+>' => 'rates',
                        //'GET materials' => 'materials',
                        'GET duplicateRate/<consumption_rate_id:\d+>' => 'duplicate-rate',
                        'POST updateMaterials' => 'update-materials',
                    ],
                    'pluralize' => true,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/figure',
                    'pluralize' => true,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/axis',
                    'pluralize' => true,
                ],
                [
                    'class' => UrlRule::class,
                    'controller' => 'v1/estimate',
                    'pluralize' => true,
                ],
            ],
        ],
        'urlManagerBackend' => [
            'class' => 'yii\web\urlManager',
            'baseUrl' => getenv('BASE_URL'),
            'enablePrettyUrl' => true,
            'showScriptName' => false,
            'rules' => [
                '' => 'site/index',
                '<controller:\w+>/<action:\w+>/' => '<controller>/<action>',
            ],
        ],
        'mailer' => [
            'viewPath' => '@api/mail',
        ],
        'cache' => [
            'class' => FileCache::class,
        ],
    ],
    'params' => $params,
    'as CorsFilter' => [
        'class' => Cors::class,
        'cors' => [
            'Origin' => ['*'],
            'Access-Control-Request-Method' => ['GET', 'POST', 'PUT', 'PATCH', 'DELETE', 'HEAD', 'OPTIONS'],
            'Access-Control-Request-Headers' => ['*'],
            'Access-Control-Allow-Credentials' => null,
            'Access-Control-Max-Age' => 86400,
            'Access-Control-Expose-Headers' => [],
        ],
    ],
];
