<?php

namespace api\modules\v1\controllers;

use api\modules\v1\models\ConsumptionRate;
use common\entities\Dictionaries\ConsumptionRatesMaterial;
use common\services\ConsumptionRatesMaterialService;
use Yii;
use yii\base\Module;
use yii\db\ActiveRecord;
use yii\web\NotFoundHttpException;

/**
 * Контроллер справочника норм расхода.
 */
class ConsumptionRateController extends BaseRestController
{
    public $modelClass = ConsumptionRate::class;
    private ConsumptionRatesMaterialService $materialService;

    /** @param array<string> $config */
    public function __construct(
        string $id,
        Module $module,
        ConsumptionRatesMaterialService $materialService,
        array $config = []
    ) {
        parent::__construct($id, $module, $config);

        $this->materialService = $materialService;
    }

    public function actions(): array
    {
        $actions = parent::actions();

        unset($actions['update'], $actions['delete']);

        return $actions;
    }

    /**
     * Получение массива норм расхода по ID работы из перечня.
     */
    public function actionRates(): array
    {
        $rates = [];
        $workId = $this->getWorkIdFromRequest();

        foreach (ConsumptionRate::find()->where(['work_list_id' => $workId])->all() as $conRate) {
            $id = $conRate->id;
            $name = $conRate->workList->name;
            $rates[] = compact('id', 'name');
        }

        return $rates;
    }

    /**
     * Дублирование записи нормы расхода.
     */
    public function actionDuplicateRate(): bool
    {
        $rateId = $this->getRateIdFromRequest();
        $rate = ConsumptionRate::find()->where(['id' => $rateId])->limit(1)->one();
        $newRate = new ConsumptionRate();
        $newRate->setAttributes($rate->getAttributes());
        $newRate->save();

        foreach ($rate->materials as $material) {
            $newMaterial = new ConsumptionRatesMaterial();
            $newMaterial->setAttributes($material->getAttributes());
            $newMaterial->consumption_rate_id = $newRate->id;

            $newMaterial->save();
        }

        return true;
    }

    /**
     * Обновление материалов нормы расхода.
     */
    public function actionUpdateMaterials(): bool
    {
        $data = Yii::$app->getRequest()->getBodyParam('materials');
        $this->materialService->batchUpdate($data);

        return true;
    }

    protected function verbs(): array
    {
        $verbs = parent::verbs();

        unset($verbs['update'], $verbs['delete']);

        return $verbs;
    }

    /**
     * Поиск нормы расхода по идентификатору.
     *
     * @return array|ActiveRecord|null
     * @throws NotFoundHttpException
     */
    public function findModel(int $id)
    {
        $model = ConsumptionRate::find()
            ->where([
                'id' => $id,
            ])
            ->one();

        if ($model) {
            return $model;
        }

        throw new NotFoundHttpException('Запрошенная норма не найдена.');
    }

    /**
     * Возвращает ID работы из строки запроса.
     */
    private function getWorkIdFromRequest(): int
    {
        return (int) Yii::$app->getRequest()->getQueryParam('work_id');
    }

    /**
     * Возвращает ID нормы расхода из строки запроса.
     */
    private function getRateIdFromRequest(): int
    {
        return (int) Yii::$app->getRequest()->getQueryParam('consumption_rate_id');
    }
}
