<?php

namespace api\modules\v1\controllers;

use common\entities\Project\Figure;
use common\entities\Contract\ContractEstimate;
use common\entities\Project\Axis;
use common\entities\Project\ProjectImage;
use common\entities\Project\ProjectWorksContractor;
use common\helpers\ProjectHelper;
use Yii;
use yii\base\Exception;
use yii\helpers\Url;
use yii\web\HttpException;

/**
 * Контроллер справочника работ.
 */
class ProjectController extends BaseRestController
{
    public $modelClass = ProjectWorksContractor::class;

    public function actions(): array
    {
        $actions = parent::actions();

        unset($actions['update'], $actions['delete']);

        return $actions;
    }

    /**
     * @throws HttpException
     */
    public function actionEstimates(): array
    {
        $projectId = $this->getProjectIdFromRequest();
        $model = ProjectWorksContractor::find()->where(['id' => $projectId])->limit(1)->one();
        if ($model) {
            $estimates = ContractEstimate::find()->where(['contract_id' => $model->contract_id])->andWhere(['work_type_id' => $model->work_type_id])->all();
        } else {
            throw new HttpException(404, 'Проект не найден');
        }
        return $estimates;
    }

    /** @throws Exception */
    public function actionImages(): array
    {
        $imagesResult = [];
        $projectId = $this->getProjectIdFromRequest();
        $model = ProjectWorksContractor::find()->where(['id' => $projectId])->limit(1)->one();
        if ($model) {
            $images = ProjectImage::find()->where(['contract_id' => $model->contract_id])->andWhere(['work_type_id' => $model->work_type_id])->all();
        } else {
            throw new HttpException(404, 'Проект не найден');
        }

        foreach ($images as $image) {
            $id = $image->id;
            $path = ProjectHelper::getImageSourcePath($image->pdf_name) . '/' . $image->name;
            $imagesResult[] = compact('id', 'path');
        }

        return $imagesResult;
    }

    /** @throws Exception */
    public function actionImage(): array
    {
        $images = [];
        $imageId = $this->getImageIdFromRequest();
        $model = ProjectImage::find()->where(['id' => $imageId])->one();
        if ($model) {
            $id = $model->id;
            $path = getenv('BASE_URL') . ProjectHelper::getImageUrl($model->pdf_name) . '/' . $model->name;
            $workType = $model->workType->name;
            $stage = $model->stage;
            $images[] = compact('id', 'path', 'workType', 'stage');

            return $images;
        } else {
            throw new HttpException(404, 'Изображение не найдено');
        }
    }

    /**
     * @throws HttpException
     */
    public function actionFigures(): array
    {
        $imageId = $this->getImageIdFromRequest();
        $model = ProjectImage::find()->where(['id' => $imageId])->one();
        if ($model) {
            $figures = Figure::find()->where(['image_id' => $model->id])->all();
        } else {
            throw new HttpException(404, 'Изображение не найдено');
        }
        return $figures;
    }

    /**
     * @throws HttpException
     */
    public function actionAxes(): array
    {
        $imageId = $this->getImageIdFromRequest();
        $model = ProjectImage::find()->where(['id' => $imageId])->one();
        if ($model) {
            $axes = Axis::find()->where(['image_id' => $model->id])->all();
        } else {
            throw new HttpException(404, 'Изображение не найдено');
        }
        return $axes;
    }

    protected function verbs(): array
    {
        $verbs = parent::verbs();

        unset($verbs['update'], $verbs['delete']);

        return $verbs;
    }

    /**
     * Возвращает ID проекта из строки запроса.
     */
    private function getProjectIdFromRequest(): int
    {
        return (int) Yii::$app->getRequest()->getQueryParam('project_id');
    }

    /**
     * Возвращает ID изображения из строки запроса.
     */
    private function getImageIdFromRequest(): int
    {
        return (int) Yii::$app->getRequest()->getQueryParam('image_id');
    }
}
