<?php

namespace api\tests\api;

use api\tests\ApiTester;
use common\fixtures\ConsumptionRateFixture;
use common\fixtures\ConsumptionRatesMaterialFixture;
use common\fixtures\UnitMeasureFixture;
use common\fixtures\WorkListFixture;
use common\fixtures\WorkListsMaterialFixture;

class ConsumptionRateCest
{
    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'consumptionRate' => [
                'class' => ConsumptionRateFixture::class,
                'dataFile' => codecept_data_dir() . 'consumption_rate.php',
            ],
            'unitMeasure' => [
                'class' => UnitMeasureFixture::class,
                'dataFile' => codecept_data_dir() . 'unit_measure.php',
            ],
            'workList' => [
                'class' => WorkListFixture::class,
                'dataFile' => codecept_data_dir() . 'work_list.php',
            ],
            'workListsMaterial' => [
                'class' => WorkListsMaterialFixture::class,
                'dataFile' => codecept_data_dir() . 'work_lists_material.php',
            ],
            'consumptionRatesMaterial' => [
                'class' => ConsumptionRatesMaterialFixture::class,
                'dataFile' => codecept_data_dir() . 'consumption_rates_material.php',
            ],
        ];
    }

    public function success(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/consumption-rates/1');
        $I->seeResponseCodeIs(200);
        $I->seeResponseIsJson();
        $I->seeResponseContainsJson([
            'id' => 1,
            'work' => 'покраска подготовленной деревянной двери',
            'work_scope' => '42.00',
            'work_unit_cost' => '6874.00',
            'materials_count' => 2,
        ]);
    }

    public function successRates(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/consumption-rates/rates/1');
        $I->seeResponseCodeIs(200);
        $I->seeResponseIsJson();
        $I->seeResponseContainsJson([
            [
                'id' => 1,
                'name' => 'покраска подготовленной деревянной двери',
            ],
        ]);
    }

    public function duplicateRate(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/consumption-rates/duplicateRate/1');
        $I->seeResponseCodeIs(200);
    }

    public function updateMaterials(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendPOST('v1/consumption-rates/updateMaterials', [
            'materials' => [
                [
                    'id' => 1,
                    'consumption_rate_id' => 1,
                    'material_id' => 1,
                    'material_expense' => 490,
                    'material_unit_cost' => 560,
                    'sort' => 1,
                ],
            ],
        ]);
        $I->seeResponseCodeIs(200);
    }

    public function error(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/consumption-rates/10');
        $I->seeResponseCodeIs(404);
        $I->seeResponseIsJson();
    }
}
