<?php

namespace api\tests\api;

use api\tests\ApiTester;
use common\fixtures\CompanyFixture;
use common\fixtures\ContractCompanyFixture;
use common\fixtures\ContractFixture;
use common\fixtures\ProjectImageFixture;
use common\fixtures\ProjectWorksContractorFixture;
use common\fixtures\WorkTypeFixture;
use common\helpers\ProjectHelper;

class ProjectImageCest
{
    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'contract' => [
                'class' => ContractFixture::class,
                'dataFile' => codecept_data_dir() . 'contract.php',
            ],
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'contractCompany' => [
                'class' => ContractCompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'contract_company.php',
            ],
            'projectImage' => [
                'class' => ProjectImageFixture::class,
                'dataFile' => codecept_data_dir() . 'project_image.php',
            ],
            'projectWorksContractor' => [
                'class' => ProjectWorksContractorFixture::class,
                'dataFile' => codecept_data_dir() . 'project_work_contractor.php',
            ],
        ];
    }

    public function success(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/project/1/images');
        $I->seeResponseCodeIs(200);
        $I->seeResponseIsJson();
        $I->seeResponseContainsJson([
            [
                'id' => 1,
                'path' => ProjectHelper::getImageSourcePath('test.pdf') . '/' . '1.jpg',
            ],
            [
                'id' => 2,
                'path' => ProjectHelper::getImageSourcePath('test.pdf') . '/' . '2.jpg',
            ],
        ]);
    }

    public function error(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/project/10/images');
        $I->seeResponseCodeIs(404);
        $I->seeResponseIsJson();
    }
}
