<?php

namespace api\tests\api;

use api\tests\ApiTester;
use common\fixtures\UnitMeasureFixture;
use common\fixtures\WorkListFixture;
use common\fixtures\WorkTypeFixture;

class WorkListCest
{
    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'workList' => [
                'class' => WorkListFixture::class,
                'dataFile' => codecept_data_dir() . 'work_list.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'unitMeasure' => [
                'class' => UnitMeasureFixture::class,
                'dataFile' => codecept_data_dir() . 'unit_measure.php',
            ],
        ];
    }

    public function success(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/work-lists/1');
        $I->seeResponseCodeIs(200);
        $I->seeResponseIsJson();
        $I->seeResponseContainsJson([
            'id' => 1,
            'name' => 'покраска подготовленной деревянной двери',
            'alias' => 'покраска двери',
            'description' => 'Описание',
        ]);
    }

    public function successWorks(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/work-lists/works');
        $I->seeResponseCodeIs(200);
        $I->seeResponseIsJson();
        $I->seeResponseContainsJson([
            [
                'id' => 1,
                'name' => 'покраска подготовленной деревянной двери',
            ],
        ]);
    }

    public function error(ApiTester $I): void
    {
        $I->haveHttpHeader('apiKey', getenv('API_KEY'));
        $I->sendGET('v1/work-lists/10');
        $I->seeResponseCodeIs(404);
        $I->seeResponseIsJson();
    }
}
