<?php

namespace backend\controllers;

use DomainException;
use Yii;
use common\auth\Identity;
use common\services\auth\AuthService;
use yii\base\Module;
use common\forms\auth\LoginForm;
use yii\web\Response;

class AuthController extends CrudController
{
    private AuthService $authService;

    /** @param array<string> $config */
    public function __construct(string $id, Module $module, AuthService $service, array $config = [])
    {
        parent::__construct($id, $module, $config);

        $this->authService = $service;
    }

    /**
     * Вход в учетную запись
     *
     * @return string|Response
     */
    public function actionLogin()
    {
        if (!Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $this->layout = 'main-login';

        $form = new LoginForm();
        if ($form->load(Yii::$app->request->post()) && $form->validate()) {
            try {
                $user = $this->authService->auth($form);
                Yii::$app->user->login(new Identity($user), $form->rememberMe ? 3600 * 24 * 30 : 0);
                return $this->goBack();
            } catch (DomainException $e) {
                Yii::$app->errorHandler->logException($e);
                Yii::$app->session->setFlash('error', $e->getMessage());
            }
        }

        return $this->render('login', [
            'model' => $form,
        ]);
    }

    /**
     * Выход из учетной записи
     */
    public function actionLogout(): Response
    {
        Yii::$app->user->logout();

        return $this->goHome();
    }
}
