<?php

namespace backend\controllers\contract;

use backend\controllers\CrudController;
use Throwable;
use Yii;
use common\entities\Contract\ContractExpense;
use yii\data\ActiveDataProvider;
use yii\db\StaleObjectException;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * ContractExpenseController реализует CRUD операции над связанными расходами.
 */
class ContractExpenseController extends CrudController
{
    public function actions(): array
    {
        return [
            'history' => [
                'class' => 'common\modules\entitiesHistory\actions\IndexAction',
                'modelClass' => 'common\entities\Contract\ContractExpense',
                'viewFile' => 'index_history',
                'pageSize' => 20,
            ],
        ];
    }

    /**
     * Lists all ContractExpense models.
     */
    public function actionIndex(): string
    {
        $dataProvider = new ActiveDataProvider([
            'query' => ContractExpense::find(),
        ]);

        return $this->render('index', [
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single ContractExpense model.
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView(int $id): string
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new ContractExpense model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return string|Response
     */
    public function actionCreate(int $contractId)
    {
        $model = new ContractExpense();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['contract/view', 'id' => $contractId]);
        }

        return $this->render('create', [
            'model' => $model,
            'contractId' => $contractId,
        ]);
    }

    /**
     * Updates an existing ContractExpense model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @return string|Response
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate(int $id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['contract/view', 'id' => $model->contract_id]);
        }

        return $this->render('update', [
            'model' => $model,
            'contractId' => $model->contract_id,
        ]);
    }

    /**
     * Deletes an existing ContractWork model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @throws NotFoundHttpException if the model cannot be found
     * @throws Throwable
     * @throws StaleObjectException
     */
    public function actionDelete(int $id): Response
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the ContractExpense model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @return ContractExpense the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id): ContractExpense
    {
        if (($model = ContractExpense::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('Страницы не существует.');
    }
}
