<?php

namespace backend\controllers\dictionaries;

use backend\controllers\CrudController;
use Throwable;
use Yii;
use common\entities\Dictionaries\UnitMeasure;
use yii\data\ActiveDataProvider;
use yii\db\IntegrityException;
use yii\db\StaleObjectException;
use yii\web\ForbiddenHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * UnitMeasureController реализует CRUD операции над единицами измерений.
 */
class UnitMeasureController extends CrudController
{
    /**
     * Lists all UnitMeasure models.
     */
    public function actionIndex(): string
    {
        $dataProvider = new ActiveDataProvider([
            'query' => UnitMeasure::find(),
        ]);

        return $this->render('index', [
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single UnitMeasure model.
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView(int $id): string
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new UnitMeasure model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return string|Response
     */
    public function actionCreate()
    {
        $model = new UnitMeasure();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing UnitMeasure model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @return string|Response
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate(int $id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing UnitMeasure model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @throws NotFoundHttpException if the model cannot be found
     * @throws StaleObjectException
     * @throws Throwable
     */
    public function actionDelete(int $id): Response
    {
        try {
            $this->findModel($id)->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }

        return $this->redirect(['index']);
    }

    /**
     * Finds the UnitMeasure model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @return UnitMeasure the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel(int $id): UnitMeasure
    {
        if ($model = UnitMeasure::findOne($id)) {
            return $model;
        }

        throw new NotFoundHttpException('Страница не найдена.');
    }
}
