<?php

namespace backend\controllers\dictionaries;

use backend\controllers\CrudController;
use Throwable;
use Yii;
use common\entities\Dictionaries\WorkType;
use yii\data\ActiveDataProvider;
use yii\db\IntegrityException;
use yii\db\StaleObjectException;
use yii\web\ForbiddenHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * WorkTypeController реализует CRUD операции над типом работ.
 */
class WorkTypeController extends CrudController
{
    /**
     * Lists all WorkType models.
     */
    public function actionIndex(): string
    {
        $dataProvider = new ActiveDataProvider([
            'query' => WorkType::find(),
        ]);

        return $this->render('index', [
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single WorkType model.
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView(int $id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new WorkType model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return Response|string
     */
    public function actionCreate()
    {
        $model = new WorkType();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing WorkType model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @return Response|string
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate(int $id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing WorkType model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @throws NotFoundHttpException if the model cannot be found
     * @throws StaleObjectException
     * @throws Throwable
     */
    public function actionDelete(int $id): Response
    {
        try {
            $this->findModel($id)->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }

        return $this->redirect(['index']);
    }

    /**
     * Finds the WorkType model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @return WorkType the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel(int $id): WorkType
    {
        if ($model = WorkType::findOne($id)) {
            return $model;
        }

        throw new NotFoundHttpException('Страница не найдена.');
    }
}
