<?php

namespace backend\tests\functional;

use backend\tests\FunctionalTester;
use common\fixtures\CompanyFixture;
use common\fixtures\ContractCompanyFixture;
use common\fixtures\ContractFixture;
use common\fixtures\UserFixture;
use common\fixtures\WorkTypeFixture;

/**
 * Class ContractCest
 */
class ContractCest
{
    private string $formId = '#contract-form';

    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'user' => [
                'class' => UserFixture::class,
                'dataFile' => codecept_data_dir() . 'login_data.php',
            ],
            'contract' => [
                'class' => ContractFixture::class,
                'dataFile' => codecept_data_dir() . 'contract.php',
            ],
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'contractCompany' => [
                'class' => ContractCompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'contract_company.php',
            ],
        ];
    }

    public function _before(FunctionalTester $I)
    {
        $I->amOnRoute('auth/login');
        $I->fillField('#loginform-username', 'erau');
        $I->fillField('#loginform-password', 'password_0');
        $I->click('login-button');
    }

    public function submitNoData(FunctionalTester $I)
    {
        $I->amOnRoute('contract/create', ['companyId' => '1']);
        $I->submitForm($this->formId, []);
        $I->seeInTitle('Добавление договора');
        $I->see('Необходимо заполнить «Номер договора».');
        $I->see('Необходимо заполнить «Число закрытия документов».');
    }

    public function createContract(FunctionalTester $I): void
    {
        $I->amOnRoute('contract/create', ['companyId' => '1']);
        $I->submitForm($this->formId, [
            'ContractForm[number]' => '463467',
            'ContractForm[date_start]' => '2019-12-12',
            'ContractForm[documents_day_end]' => 12,
            'ContractForm[status]' => 30,
            'ContractForm[is_act_counter_increase_annually]' => 1,
            'ContractForm[subject_address]' => 'Москва, ул. Строителей, д.3',
            'ContractForm[subject_name]' => 'Стройка',
        ]);

        $I->dontSeeElement($this->formId);
    }
}
