<?php

namespace backend\tests\functional;

use backend\tests\FunctionalTester;
use common\fixtures\CompanyFixture;
use common\fixtures\ContractCompanyFixture;
use common\fixtures\ContractFixture;
use common\fixtures\UnitMeasureFixture;
use common\fixtures\UserFixture;
use common\fixtures\WorkListFixture;
use common\fixtures\WorkTypeFixture;

/**
 * Class ContractEstimateCest
 */
class ContractEstimateCest
{
    private string $formId = '#contract-estimate-form';

    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'user' => [
                'class' => UserFixture::class,
                'dataFile' => codecept_data_dir() . 'login_data.php',
            ],
            'unitMeasure' => [
                'class' => UnitMeasureFixture::class,
                'dataFile' => codecept_data_dir() . 'unit_measure.php',
            ],
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'workList' => [
                'class' => WorkListFixture::class,
                'dataFile' => codecept_data_dir() . 'work_list.php',
            ],
            'contract' => [
                'class' => ContractFixture::class,
                'dataFile' => codecept_data_dir() . 'contract.php',
            ],
            'contractCompany' => [
                'class' => ContractCompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'contract_company.php',
            ],
        ];
    }

    public function _before(FunctionalTester $I): void
    {
        $I->amOnRoute('auth/login');
        $I->fillField('#loginform-username', 'erau');
        $I->fillField('#loginform-password', 'password_0');
        $I->click('login-button');
    }

    public function submitNoData(FunctionalTester $I): void
    {
        $I->amOnRoute('contract-estimate/create', ['contractId' => 1]);
        $I->submitForm($this->formId, []);
        $I->seeInTitle('Добавление сметы');
        $I->see('Необходимо заполнить «Тип работы из справочника».');
        $I->see('Необходимо заполнить «Поверхность».');
        $I->see('Необходимо заполнить «Номер счета/накладной».');
        $I->see('Необходимо заполнить «Работа».');
        $I->see('Необходимо заполнить «Тип работы».');
        $I->see('Необходимо заполнить «Ответственный за исполнение».');
        $I->see('Необходимо заполнить «Количество».');
        $I->see('Необходимо заполнить «Цена за единицу».');
    }

    public function submitWrongData(FunctionalTester $I): void
    {
        $I->amOnRoute('contract-estimate/create', ['contractId' => 1]);
        $I->submitForm($this->formId, [
            'ContractEstimateForm[quantity]' => 'test',
            'ContractEstimateForm[price_per_unit]' => 'test',
            'ContractEstimateForm[markup]' => 200,
        ]);
        $I->seeInTitle('Добавление сметы');
        $I->see('Значение «Количество» должно быть числом.');
        $I->see('Значение «Цена за единицу» должно быть числом.');
        $I->see('Значение «Наценка» не должно превышать 100.');
    }

    public function createContractEstimate(FunctionalTester $I): void
    {
        $I->amOnRoute('contract-estimate/create', ['contractId' => 1]);
        $I->submitForm($this->formId, [
            'ContractEstimateForm[work_type_id]' => 1,
            'ContractEstimateForm[surface]' => 30,
            'ContractEstimateForm[bill_number]' => 'number',
            'ContractEstimateForm[bill_date]' => '2019-12-12',
            'ContractEstimateForm[work_list_id]' => 1,
            'ContractEstimateForm[type]' => 20,
            'ContractEstimateForm[contractor_id]' => 1,
            'ContractEstimateForm[quantity]' => 450,
            'ContractEstimateForm[price_per_unit]' => 20,
            'ContractEstimateForm[markup]' => 5,
        ]);

        $I->dontSeeElement($this->formId);
    }
}
