<?php

namespace backend\tests\functional;

use backend\tests\FunctionalTester;
use common\fixtures\CompanyFixture;
use common\fixtures\ContractCompanyFixture;
use common\fixtures\ContractFixture;
use common\fixtures\UserFixture;
use common\fixtures\WorkTypeFixture;

/**
 * Class ContractCest
 */
class ContractExpenseCest
{
    private string $formId = '#contract-expense-form';

    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'user' => [
                'class' => UserFixture::class,
                'dataFile' => codecept_data_dir() . 'login_data.php',
            ],
            'contract' => [
                'class' => ContractFixture::class,
                'dataFile' => codecept_data_dir() . 'contract.php',
            ],
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'contractCompany' => [
                'class' => ContractCompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'contract_company.php',
            ],
        ];
    }

    public function _before(FunctionalTester $I)
    {
        $I->amOnRoute('auth/login');
        $I->fillField('#loginform-username', 'erau');
        $I->fillField('#loginform-password', 'password_0');
        $I->click('login-button');
    }

    public function submitNoData(FunctionalTester $I)
    {
        $I->amOnRoute('contract-expense/create', ['contractId' => '1']);
        $I->submitForm($this->formId, []);
        $I->seeInTitle('Добавление расхода');
        $I->see('Необходимо заполнить «Тип расхода».');
        $I->see('Необходимо заполнить «Сумма».');
        $I->see('Необходимо заполнить «Ответственный за покупку».');
        $I->see('Необходимо заполнить «Дополнительный комментарий».');
    }

    public function createContractExpense(FunctionalTester $I): void
    {
        $I->amOnRoute('contract-expense/create', ['contractId' => '1']);
        $I->submitForm($this->formId, [
            'ContractExpense[expense_type]' => 30,
            'ContractExpense[amount]' => 325,
            'ContractExpense[contractor_id]' => 1,
            'ContractExpense[comment]' => 'Коммментарий',
        ]);

        $I->dontSeeElement($this->formId);
    }
}
