<?php

namespace backend\tests\functional;

use backend\tests\FunctionalTester;
use common\fixtures\CompanyFixture;
use common\fixtures\ContractCompanyFixture;
use common\fixtures\ContractFixture;
use common\fixtures\UserFixture;
use common\fixtures\WorkTypeFixture;

/**
 * Class ContractCest
 */
class ContractWorkCest
{
    private string $formId = '#contract-work-form';

    /**
     * Load fixtures before db transaction begin
     * Called in _before()
     * @see \Codeception\Module\Yii2::_before()
     * @see \Codeception\Module\Yii2::loadFixtures()
     */
    public function _fixtures(): array
    {
        return [
            'user' => [
                'class' => UserFixture::class,
                'dataFile' => codecept_data_dir() . 'login_data.php',
            ],
            'contract' => [
                'class' => ContractFixture::class,
                'dataFile' => codecept_data_dir() . 'contract.php',
            ],
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'contractCompany' => [
                'class' => ContractCompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'contract_company.php',
            ],
        ];
    }

    public function _before(FunctionalTester $I)
    {
        $I->amOnRoute('auth/login');
        $I->fillField('#loginform-username', 'erau');
        $I->fillField('#loginform-password', 'password_0');
        $I->click('login-button');
    }

    public function submitNoData(FunctionalTester $I)
    {
        $I->amOnRoute('contract-work/create', ['contractId' => '1']);
        $I->submitForm($this->formId, []);
        $I->seeInTitle('Добавление сроков работы');
        $I->see('Необходимо заполнить «Тип работы».');
    }

    public function createContractWork(FunctionalTester $I): void
    {
        $I->amOnRoute('contract-work/create', ['contractId' => '1']);
        $I->submitForm($this->formId, [
            'ContractWork[work_type_id]' => '1',
            'ContractWork[date_start]' => '12.12.2019',
            'ContractWork[date_end]' => '12.12.2021',
        ]);

        $I->dontSeeElement($this->formId);
    }
}
