<?php

namespace backend\tests\unit;

use common\forms\ProjectUploadPdfForm;
use PHPUnit\Framework\TestCase;
use yii\base\ErrorException;
use yii\base\Exception;
use yii\helpers\FileHelper;
use yii\web\UploadedFile;

class ProjectUploadPdfTest extends TestCase
{
    protected string $uploadDir;

    /** @throws Exception */
    protected function setUp(): void
    {
        parent::setUp();

        $this->uploadDir = codecept_data_dir() . 'upload';
        if (!file_exists($this->uploadDir)) {
            FileHelper::createDirectory($this->uploadDir);
        }
        $this->generateFakeFile();
    }

    private function generateFakeFileData(): array
    {
        return [
            'name' => 'test.pdf',
            'tmp_name' => codecept_data_dir() . 'test.pdf',
            'type' => 'application/pdf',
            'size' => mt_rand(1000, 10000),
            'error' => '0',
        ];
    }

    private function generateFakeFile()
    {
        $_FILES['ProjectUploadPdfForm[file]'] = $this->generateFakeFileData();
    }

    /** @throws ErrorException */
    protected function tearDown(): void
    {
        FileHelper::removeDirectory($this->uploadDir);
    }

    public function testGetInstance()
    {
        $model = new ProjectUploadPdfForm();
        $model->file = UploadedFile::getInstance($model, 'file');

        $this->assertInstanceOf(UploadedFile::class, $model->file);
    }

    public function testUploadPdf()
    {
        $model = new ProjectUploadPdfForm();
        $tmpPdf = UploadedFile::getInstance($model, 'file');
        $targetFile = $this->uploadDir . '/test.pdf';

        $tmpPdf->saveAs($targetFile, false);

        $this->assertFileExists($targetFile);
    }
}
