<?php

use common\entities\Company\CompanyTypeDictionary;
use unclead\multipleinput\MultipleInput;
use yii\helpers\Html;
use yii\bootstrap4\ActiveForm;
use yii\widgets\MaskedInput;

/** @var yii\web\View $this */
/** @var common\forms\Company\CompanyForm $model */
/** @var yii\bootstrap4\ActiveForm $form */
/** @var common\entities\Company\Company $company */
?>

<div class="company-form">

    <?php $form = ActiveForm::begin(); ?>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'full_name')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'short_name')->textInput(['maxlength' => true]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'signer_post')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'signer_name')->textInput(['maxlength' => true]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'delegate_name')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'delegate_email')->input('email') ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'delegate_phones')->widget(MultipleInput::class, [
                //'max' => 4,
                'iconSource' => 'fa',
                'columns' => [
                    [
                        'name' => 'delegate_phones',
                        //'title' => $model->getAttributeLabel('delegate_phones'),
                        'type' => MaskedInput::class,
                        'options' => [
                            'options' => ['class' => 'form-control'],
                            'mask' => '+7 (999) 999-99-99',
                            'clientOptions' => [
                                'placeholder' => '+7 (999) 999-99-99',
                            ],
                        ],
                        'attributeOptions' => [
                            'enableClientValidation' => true,
                            'validateOnChange' => true,
                        ],
                        'enableError' => true,
                    ],
                ],
            ]);
?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'general_email')->input('email') ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'company_url')
                ->widget(MaskedInput::class, ['clientOptions' => ['alias' => 'url'],
                ]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'general_phones')->widget(MultipleInput::class, [
                //'max' => 4,
                'iconSource' => 'fa',
                'columns' => [
                    [
                        'name' => 'general_phones',
                        //'title' => $model->getAttributeLabel('general_phones'),
                        'type' => MaskedInput::class,
                        'options' => [
                            'options' => ['class' => 'form-control'],
                            'mask' => '+7 (999) 999-99-99',
                            'clientOptions' => [
                                'placeholder' => '+7 (999) 999-99-99',
                            ],
                        ],
                        'attributeOptions' => [
                            'enableClientValidation' => true,
                            'validateOnChange' => true,
                        ],
                        'enableError' => true,
                    ],
                ],
            ]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'legal_adress')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'physical_adress')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'company_type')
                ->dropDownList(CompanyTypeDictionary::allTypesWithShortLabels(), ['prompt' => 'Выберите тип организации']) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'inn')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'ogrn')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'okpo')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'kpp')->textInput(['maxlength' => true]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'bank')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'bank_bic')->textInput(['maxlength' => true]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'bank_cor_account')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'payment_account')->textInput(['maxlength' => true]) ?>
        </div>
    </div>

    <div class="form-group">
        <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
        <?= Html::a('Отменить', ['index'], ['class' => 'btn btn-danger']) ?>
    </div>

    <?php ActiveForm::end(); ?>

</div>
