<?php

use yii\grid\GridView;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\bootstrap4\Modal;
use yii\bootstrap4\LinkPager;

/** @var yii\web\View $this */
/** @var yii\data\ActiveDataProvider $dataProvider */
/** @var common\forms\Company\ClientForm $model */

$this->title = 'Клиенты';
$this->params['breadcrumbs'][] = $this->title;
?>
<div class="company-index">

    <?php Modal::begin([
        'title' => 'Добавление клиента',
        'toggleButton' => ['label' => 'Добавить клиента', 'class' => 'btn btn-primary'],
        'size' => 'modal-lg',
    ]);
    echo $this->render('add_client', ['model' => $model]);
    Modal::end(); ?>

    <hr>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'tableOptions' => ['class' => 'table table-bordered table-hover'],
        'pager' => ['class' => LinkPager::class],
        'columns' => [
            //['class' => 'yii\grid\SerialColumn'],
            'id',
            //'full_name',
            [
                'attribute' => 'short_name',
                'label' => 'Наименование',
                'value' => function ($dataProvider) {
                    return Html::a(Html::encode($dataProvider->short_name), Url::to(['view', 'id' => $dataProvider->id, 'tab' => 'tab_contract']));
                },
                'format' => 'raw',
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'label' => 'Количество договоров',
                'headerOptions' => ['class' => 'text-wrap'],
                'value' => function ($dataProvider) {
                    return count($dataProvider->contracts);
                },
            ],
            [
                'label' => 'Дата завершения',
                'value' => function ($model) {
                    return $model->contractsMaxDateEnd;
                },
                'headerOptions' => ['class' => 'text-wrap'],
                'format' => 'date',
            ],
            [
                'label' => 'Активность',
                'value' => function ($model) {
                    if (!empty($model->contractsActivity)) {
                        return 'Да';
                    }
                    return 'Нет';
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            //['class' => 'yii\grid\ActionColumn'],
        ],
        'rowOptions' => function ($dataProvider) {
            $url = Url::to(['view', 'id' => $dataProvider['id'], 'tab' => 'tab_contract']);
            return [
                'onclick' => "window.location.href='{$url}'",
            ];
        },
    ]); ?>
</div>
