<?php

use common\entities\Company\CompanyTypeDictionary;
use yii\bootstrap4\LinkPager;
use yii\bootstrap4\Tabs;
use yii\grid\GridView;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\web\YiiAsset;
use yii\widgets\DetailView;

/** @var yii\web\View $this */
/** @var common\entities\Company\Company $model */
/** @var yii\data\ActiveDataProvider $contractsProvider */


$this->title = $model->full_name;
$this->params['breadcrumbs'][] = ['label' => 'Юридические лица', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;

$request = Yii::$app->request->get('tab');
$status_main = $request === null ? 'active' : '';
$status_contract = $request === 'tab_contract' ? 'active' : '';

YiiAsset::register($this);
?>
<?php
echo Tabs::widget([
    'id' => 'tabs',
    'renderTabContent' => false, // If each tab is displayed, it is custom DIV perhaps Render Other page files , Set as false.
    'linkOptions' => ['data-toggle' => 'tab'],
    'items' => [
        [
            'label' => 'Информация о заказчике',
            'options' => ['id' => 'tab_main'],
            'active' => $request === null,
        ],
        [
            'label' => 'Информация о договорах заказчика',
            'options' => ['id' => 'tab_contract'],
            'active' => $request === 'tab_contract',
            'visible' => $model->is_client == 1,
        ],
    ],
]);
?>
<div class="tab-content">
    <div class="tab-pane <?= $status_main; ?>" id="tab_main">
        <hr>
        <div class="company-view">
            <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
            <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
                'class' => 'btn btn-danger',
                'data' => [
                    'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                    'method' => 'post',
                ],
            ]) ?>
            <hr>
            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    'full_name',
                    'short_name',
                    'delegate_name',
                    [
                        'attribute' => 'delegate_phones',
                        'value' => function ($model) {
                            $delegate_phones = $model->delegate_phones->toArray();
                            return implode(', ', $delegate_phones);
                        },
                    ],
                    'delegate_email:email',
                    'signer_post',
                    'signer_name',
                    [
                        'attribute' => 'general_phones',
                        'value' => function ($model) {
                            $general_phones = $model->general_phones->toArray();
                            return implode(', ', $general_phones);
                        },
                    ],
                    'general_email:email',
                    'legal_adress',
                    'physical_adress',
                    [
                        'attribute' => 'company_type',
                        'value' => CompanyTypeDictionary::fullTypeName($model->company_type),
                    ],
                    'inn',
                    'ogrn',
                    'okpo',
                    'kpp',
                    'company_url:url',
                    'payment_account',
                    'bank',
                    'bank_cor_account',
                    'bank_bic',
                    'created_at:datetime',
                    'updated_at:datetime',
                ],
            ]) ?>
        </div>
    </div>

    <div class="tab-pane <?= $status_contract; ?>" id="tab_contract">
        <hr>
        <div class="contract-view">
            <?= Html::a('Добавить договор', ['contract/create', 'companyId' => $model->id], ['class' => 'btn btn-primary']) ?>
            <hr>
            <?= GridView::widget([
                'dataProvider' => $contractsProvider,
                'tableOptions' => ['class' => 'table table-bordered table-hover'],
                'pager' => ['class' => LinkPager::class],
                'columns' => [
                    'id',
                    [
                        'attribute' => 'number',
                        'value' => function ($model) {
                            return Html::a(Html::encode($model->number), Url::to(['contract/view', 'id' => $model->id]));
                        },
                        'format' => 'raw',
                    ],
                    'date_start:date',
                    [
                        'label' => 'Дата завершения',
                        'value' => function ($contractsProvider) {
                            return $contractsProvider->lastDateEndContractWorks;
                        },
                        'format' => 'date',
                    ],
                    [
                        'label' => 'Прогресс договора',
                        'value' => function ($contractsProvider) {
                            return $contractsProvider->progress . '%';
                        },
                    ],
                    [
                        'attribute' => 'status',
                        'value' => function ($contractsProvider) {
                            return $contractsProvider->statusName;
                        },
                    ],
                    ['class' => 'yii\grid\ActionColumn',
                        'header' => 'Опции',
                        'template' => '{view} {update} ',
                        'urlCreator' => function ($action, $model) {
                            if ($action === 'view') {
                                return ['contract/view', 'id' => $model->id];
                            }
                            if ($action === 'update') {
                                return ['contract/update', 'id' => $model->id];
                            }
                        },
                    ],
                ],
            ]); ?>
        </div>
    </div>
</div>
