<?php

use common\entities\Dictionaries\WorkListsMaterial;
use unclead\multipleinput\MultipleInput;
use yii\bootstrap4\ActiveForm;
use yii\helpers\Html;

/** @var yii\web\View $this */
/** @var common\entities\Dictionaries\ConsumptionRate $model */
/** @var yii\bootstrap4\ActiveForm $form */

$this->title = $model->workList->name;
?>

<div class="work-list-form">
    <p>
        <?= Html::a(
            'Добавить материал',
            [
                'work-list/update',
                'id' => $model->work_list_id,
                'rate' => $model->id,
            ],
            ['class' => 'btn btn-primary']
        ) ?>
    </p>

    <?php $form = ActiveForm::begin(); ?>
    <?= $form->errorSummary($model) ?>
    <?= MultipleInput::widget([
        'id' => 'mpi',
        'name' => 'ConsumptionRatesMaterial',
        'data' => $model->consumptionRateMaterials,
        'allowEmptyList' => false,
        'sortable' => true,
        'iconSource' => 'fa',
        'addButtonOptions' => ['class' => 'd-none'],
        'removeButtonOptions' => ['class' => 'd-none'],
        'attributeOptions' => [
            'enableAjaxValidation' => true,
            'enableClientValidation' => true,
            'validateOnChange' => true,
            'validateOnSubmit' => true,
            'validateOnBlur' => false,
        ],
        'columns' => [
            [
                'name' => 'material_id',
                'title' => 'Материал',
                'type' => 'dropDownList',
                'items' => WorkListsMaterial::workMaterialsList(),
                'options' => [
                    'prompt' => 'Выберите материал',
                    'options' => ['class' => 'form-control'],
                    'required' => 'required',
                    'readonly' => 'readonly',
                ],
            ],
            [
                'name' => 'unit_measure',
                'title' => 'Единица измерения',
                'type' => 'textInput',
                'value' => function ($data) {
                    return $data->workListsMaterial->unitMeasure->alias;
                },
                'options' => [
                    'readonly' => 'readonly',
                ],
            ],
            [
                'name' => 'material_expense',
                'title' => 'Расход материала',
                'type' => 'textInput',
                'options' => [
                    'type' => 'number',
                    'step' => '0.01',
                    'required' => 'required',
                ],
            ],
            [
                'name' => 'material_unit_cost',
                'title' => 'Стоимость за единицу материала',
                'type' => 'textInput',
                'options' => [
                    'type' => 'number',
                    'step' => '0.01',
                    'required' => 'required',
                ],
            ],
            [
                'name' => 'id',
                'type' => 'hiddenInput',
            ],
            [
                'name' => 'consumption_rate_id',
                'type' => 'hiddenInput',
            ],
        ],
    ]) ?>

    <div class="form-group">
        <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
    </div>

    <?php ActiveForm::end(); ?>
</div>
