<?php

use common\helpers\DecimalNumberHelper;
use common\widgets\RelatedList;
use yii\bootstrap4\Tabs;
use yii\helpers\Html;
use yii\widgets\DetailView;
use yii\web\YiiAsset;

/** @var yii\web\View $this */
/** @var common\entities\Dictionaries\ConsumptionRate $model */

$this->title = $model->workList->name;
$this->params['breadcrumbs'][] = ['label' => 'Нормы расхода', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
YiiAsset::register($this);
?>
<?php
echo Tabs::widget([
    'id' => 'tabs',
    'renderTabContent' => false, // If each tab is displayed, it is custom DIV perhaps Render Other page files , Set as false.
    'linkOptions' => ['data-toggle' => 'tab'],
    'items' => [
        [
            'label' => 'Общая информация',
            'options' => ['id' => 'tab_main'],
            'active' => true,
        ],
        [
            'label' => 'Материалы',
            'options' => ['id' => 'tab_material'],
            'visible' => !empty($model->consumptionRateMaterials),
        ],
    ],
]);
?>
<div class="tab-content">
    <div class="tab-pane active" id="tab_main">
        <hr>
        <div class="consumption-rate-view">
            <p>
                <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Материалы', ['update-materials', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
                    'class' => 'btn btn-danger',
                    'data' => [
                        'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                        'method' => 'post',
                    ],
                ]) ?>
            </p>

            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    [
                        'label' => 'Работа',
                        'value' => function ($model) {
                            return $model->workList->name;
                        },
                    ],
                    [
                        'label' => 'Единица измерения работы',
                        'value' => function ($model) {
                            return $model->workList->unitMeasure->alias;
                        },
                    ],
                    [
                        'attribute' => 'work_scope',
                        'value' => function ($model) {
                            return DecimalNumberHelper::numFormat($model->work_scope);
                        },
                    ],
                    [
                        'attribute' => 'work_unit_cost',
                        'value' => function ($model) {
                            return DecimalNumberHelper::numFormat($model->work_unit_cost);
                        },
                    ],
                    [
                        'label' => 'Стоимость работы',
                        'value' => function ($model) {
                            return DecimalNumberHelper::numFormat($model->workAmount());
                        },
                    ],
                    [
                        'label' => 'Стоимость материалов',
                        'value' => function ($model) {
                            return DecimalNumberHelper::numFormat($model->materialsAmount());
                        },
                        'visible' => !empty($model->consumptionRateMaterials),
                    ],
                    [
                        'label' => 'Итоговая стоимость',
                        'value' => function ($model) {
                            return DecimalNumberHelper::numFormat($model->amount());
                        },
                    ],
                    'created_at:datetime',
                    'updated_at:datetime',
                ],
            ]) ?>
        </div>
    </div>

    <div class="tab-pane" id="tab_material">
        <hr>
        <div class="consumption-rate-material-view">
            <?= RelatedList::widget([
                'models' => $model->consumptionRateMaterials,
                'attributes' => [
                    'material_id',
                    'material_expense',
                    'material_unit_cost',
                ],
                'values' => [
                    'workListsMaterial' => 'name',
                    'material_expense' => 'material_expense',
                    'material_unit_cost' => 'material_unit_cost',
                ],
            ]);
?>
        </div>
    </div>
</div>
