<?php

use common\entities\Contract\ContractCompany;
use common\entities\Contract\ContractEstimate;
use common\entities\Dictionaries\WorkList;
use common\entities\Dictionaries\WorkType;
use common\helpers\DateHelper;
use kartik\date\DatePicker;
use yii\helpers\Html;
use yii\bootstrap4\ActiveForm;

/** @var yii\web\View $this */
/** @var common\entities\Contract\ContractEstimate $model */
/** @var yii\bootstrap4\ActiveForm $form */
/** @var int $contractId */
?>

<div class="contract-estimate-form">

    <?php $form = ActiveForm::begin(['id' => 'contract-estimate-form']); ?>

    <?= $form->field($model, 'contract_id')->hiddenInput(['value' => $contractId])->label(false) ?>

    <div class="row g-4">
        <div class="col">
            <?= $form->field($model, 'work_type_id')
                ->dropDownList(WorkType::workTypesList(), [
                    'prompt' => 'Выберите тип работы',
                    'readonly' => Yii::$app->controller->action->id === 'update',
                ]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'surface')
                ->dropDownList(ContractEstimate::surfaceList(), [
                    'prompt' => 'Выберите поверхность',
                    'readonly' => Yii::$app->controller->action->id === 'update',
                ]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'bill_number')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'bill_date')->widget(DatePicker::class, [
                'language' => 'ru',
                'value' => $model->bill_date = DateHelper::convert($model->bill_date, 'date', 'dd.MM.yyyy'),
                'options' => ['placeholder' => 'Выберите дату'],
                'pickerIcon' => '<i class="fa fa-calendar text-primary"></i>',
                'removeIcon' => '<i class="fa fa-trash text-danger"></i>',
                'pluginOptions' => ['autoclose' => true, 'format' => 'dd.mm.yyyy'],
            ]) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'work_list_id')->dropDownList(WorkList::workList(), ['prompt' => 'Выберите работу']) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'type')->dropDownList(ContractEstimate::typeList(), ['prompt' => 'Выберите тип']) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'contractor_id')
                ->dropDownList(ContractCompany::companiesList($contractId), ['prompt' => 'Выберите исполнителя']) ?>
        </div>
    </div>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'quantity')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'price_per_unit')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'markup')->textInput(['type' => 'number', 'min' => '0', 'max' => '100']) ?>
        </div>
    </div>

    <div class="form-group">
        <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
    </div>

    <?php ActiveForm::end(); ?>

</div>
