<?php

use common\helpers\ContractEstimateHelper;
use common\helpers\DecimalNumberHelper;
use yii\bootstrap4\LinkPager;
use yii\bootstrap4\Modal;
use yii\helpers\Html;
use yii\grid\GridView;
use yii\helpers\Url;

/** @var yii\web\View $this */
/** @var yii\data\ActiveDataProvider $dataProvider */
/** @var int $contractId */

$this->title = 'Сметы';
$this->params['breadcrumbs'][] = ['label' => 'Договор', 'url' => ['contract/view', 'id' => $contractId]];
$this->params['breadcrumbs'][] = $this->title;

$amounts = ContractEstimateHelper::amounts($dataProvider);

$this->registerJs(
    '$("body").on("click", ".history-modal", function(e){   
					e.preventDefault();
					$("#viewModal").modal("show").find(".modal-content").load($(this).attr("href"));
				});'
);
Modal::begin(['id' => 'viewModal', 'size' => 'modal-xl']);
Modal::end();
?>
<div class="estimate-amounts">
    <table class="table table-responsive table-hover table-bordered">
        <thead class="">
            <th class="text-center"><strong>Общая стоимость без НДС</strong></th>
            <th class="text-center"><strong>Общая стоимость с НДС</strong></th>
            <th class="text-center"><strong>Стоимость материалов</strong></th>
            <th class="text-center"><strong>Стоимость расходных материалов</strong></th>
            <th class="text-center"><strong>Стоимость оборудования</strong></th>
            <th class="text-center"><strong>Стоимость транспорта</strong></th>
            <th class="text-center"><strong>Стоимость оплаты труда</strong></th>
            <th class="text-center"><strong>Нормативная трудоемкость</strong></th>
        </thead>

        <tbody>
        <tr class="text-center">
            <td><?= $amounts['amount']; ?></td>
            <td><?= $amounts['amountNds']; ?></td>
            <td><?= $amounts['amountMaterials']; ?></td>
            <td><?= $amounts['amountExpMaterials']; ?></td>
            <td><?= $amounts['amountEquipment']; ?></td>
            <td><?= $amounts['amountTransport']; ?></td>
            <td><?= $amounts['amountSalary']; ?></td>
            <td><?= $amounts['salary']; ?></td>
        </tr>
        </tbody>

    </table>
</div>

<div class="contract-estimate-index">
    <p>
        <?= Html::a('Добавить смету', ['create', 'contractId' => $contractId], ['class' => 'btn btn-primary']) ?>
        <?= Html::a('История изменений', ['contract-estimate/history'], ['class' => 'history-modal btn btn-primary']); ?>
    </p>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'tableOptions' => ['class' => 'table table-responsive table-bordered table-hover'],
        'pager' => ['class' => LinkPager::class],
        'columns' => [
            [
                'class' => 'yii\grid\SerialColumn',
            ],
            [
                'label' => 'Этап',
                'value' => function ($model) {
                    return Html::a(Html::encode($model->workType->name . ' + ' . $model->surfaceName), Url::to(
                        ['contract-estimate/view', 'id' => $model->id]
                    ));
                },
                'format' => 'raw',
            ],
            [
                'attribute' => 'work_list_id',
                'value' => function ($model) {
                    return $model->workList->name;
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'bill_number',
                'label' => '№ Счета',
                'value' => function ($model) {
                    if (!empty($model->bill_date)) {
                        return $model->bill_number . ' от ' . Yii::$app->formatter->asDate($model->bill_date);
                    }

                    return $model->bill_number;
                },
            ],
            [
                'attribute' => 'type',
                'value' => function ($model) {
                    return $model->typeName;
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'contractor_id',
                'value' => function ($model) {
                    return $model->contractor->company->short_name;
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'quantity',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->quantity);
                },
            ],
            [
                'label' => 'Ед. измерения',
                'value' => function ($model) {
                    return $model->workList->unitMeasure->alias;
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'price_per_unit',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->price_per_unit);
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'markup',
                'value' => function ($model) {
                    return $model->markup . '%';
                },
            ],
            [
                'label' => 'Сумма',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->estimateAmount());
                },
                'contentOptions' => ['class' => 'text-nowrap'],
            ],
            [
                'label' => 'Сумма с НДС',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->estimateAmountWithNds());
                },
                'contentOptions' => ['class' => 'text-nowrap'],
            ],
        ],
    ]); ?>
</div>
