<?php

use common\helpers\DecimalNumberHelper;
use yii\helpers\Html;
use yii\widgets\DetailView;
use yii\web\YiiAsset;

/** @var yii\web\View $this */
/** @var common\entities\Contract\ContractEstimate $model */

$this->title = 'Смета № ' . $model->bill_number;
$this->params['breadcrumbs'][] = ['label' => 'Договор', 'url' => ['contract/view', 'id' => $model->contract->id]];
$this->params['breadcrumbs'][] = ['label' => 'Сметы', 'url' => ['index', 'contractId' => $model->contract->id]];
$this->params['breadcrumbs'][] = $this->title;
YiiAsset::register($this);
?>
<div class="contract-estimate-view">
    <p>
        <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
        <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
            'class' => 'btn btn-danger',
            'data' => [
                'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                'method' => 'post',
            ],
        ]) ?>
    </p>

    <?= DetailView::widget([
        'model' => $model,
        'attributes' => [
            'id',
            [
                'attribute' => 'contract_id',
                'value' => function ($model) {
                    return $model->contract->number;
                },
            ],
            [
                'attribute' => 'work_type_id',
                'value' => function ($model) {
                    return $model->workType->name;
                },
            ],
            [
                'attribute' => 'surface',
                'value' => function ($model) {
                    return $model->surfaceName;
                },
            ],
            [
                'attribute' => 'bill_number',
                'label' => '№ Счета',
                'value' => function ($model) {
                    if (!empty($model->bill_date)) {
                        return $model->bill_number . ' от ' . Yii::$app->formatter->asDate($model->bill_date);
                    }

                    return $model->bill_number;
                },
            ],
            [
                'attribute' => 'work_list_id',
                'value' => function ($model) {
                    return $model->workList->name;
                },
            ],
            [
                'attribute' => 'type',
                'value' => function ($model) {
                    return $model->typeName;
                },
            ],
            [
                'attribute' => 'contractor_id',
                'value' => function ($model) {
                    return $model->contractor->company->full_name;
                },
            ],
            [
                'attribute' => 'quantity',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->quantity);
                },
            ],
            [
                'attribute' => 'price_per_unit',
                'value' => function ($model) {
                    return DecimalNumberHelper::numFormat($model->price_per_unit);
                },
            ],
            [
                'attribute' => 'markup',
                'value' => function ($model) {
                    return $model->markup . '%';
                },
            ],
            'created_at:datetime',
            'updated_at:datetime',
        ],
    ]) ?>
</div>
