<?php

use common\helpers\DecimalNumberHelper;
use yii\helpers\Html;
use yii\widgets\DetailView;
use yii\web\YiiAsset;

/** @var yii\web\View $this */
/** @var common\entities\Contract\ContractExpense $model */

$this->title = 'Связанные расходы по типу: ' . $model->typeName;
$this->params['breadcrumbs'][] = [
    'label' => $model->contract->company->full_name,
    'url' => [
        'company/view',
        'id' => $model->contract->company->id,
        'tab' => 'tab_contract',
    ],
];
$this->params['breadcrumbs'][] = ['label' => 'Договор ' . $model->contract->number, 'url' => ['contract/view', 'id' => $model->contract_id]];
$this->params['breadcrumbs'][] = $this->title;
YiiAsset::register($this);
?>
<div class="contract-expense-view">
    <p>
        <?= Html::a('Редактировать', ['update', 'id' => $model->id, 'contractId' => $model->contract->id], ['class' => 'btn btn-primary']) ?>
        <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
            'class' => 'btn btn-danger',
            'data' => [
                'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                'method' => 'post',
            ],
        ]) ?>
    </p>

    <?= DetailView::widget([
        'model' => $model,
        'attributes' => [
            'id',
            [
                'attribute' => 'expense_type',
                'value' => function ($model) {
                    return $model->typeName;
                },
            ],
            [
                'label' => 'Сумма с НДС',
                'value' => function ($model) {
                    if ($model->is_nds === 0) {
                        return DecimalNumberHelper::numFormat($model->addNds());
                    } else {
                        return DecimalNumberHelper::numFormat($model->amount);
                    }
                },
            ],
            [
                'label' => 'Сумма без НДС',
                'value' => function ($model) {
                    if ($model->is_nds === 0) {
                        return DecimalNumberHelper::numFormat($model->amount);
                    } else {
                        return DecimalNumberHelper::numFormat($model->removeNds());
                    }
                },
            ],
            [
                'attribute' => 'contractor_id',
                'value' => function ($model) {
                    return $model->contractor->company->full_name;
                },
            ],
            [
                'attribute' => 'comment',
                'format' => 'raw',
            ],
        ],
    ]) ?>
</div>
