<?php

use common\entities\Company\Company;
use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use common\helpers\DateHelper;
use common\readModels\ContractReadRepository;
use common\helpers\DayHelper;
use kartik\date\DatePicker;
use unclead\multipleinput\MultipleInput;
use yii\helpers\Html;
use yii\bootstrap4\ActiveForm;

/** @var yii\web\View $this*/
/** @var common\forms\Contract\ContractForm $model*/
/** @var yii\bootstrap4\ActiveForm $form */
/** @var int $companyId */
?>

<div class="contract-form">
    <?php $form = ActiveForm::begin(['id' => 'contract-form']); ?>

    <div class="row g-3">
        <div class="col">
            <?= $form->field($model, 'number')->textInput(['maxlength' => true]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'date_start')->widget(DatePicker::class, [
                'language' => 'ru',
                'value' => $model->date_start = DateHelper::convert($model->date_start, 'date', 'dd.MM.yyyy'),
                'options' => ['placeholder' => 'Выберите дату'],
                'pickerIcon' => '<i class="fa fa-calendar text-primary"></i>',
                'removeIcon' => '<i class="fa fa-trash text-danger"></i>',
                'pluginOptions' => ['autoclose' => true, 'format' => 'dd.mm.yyyy'],
            ]) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'documents_day_end')->dropDownList(DayHelper::dayList(), ['prompt' => 'Выберите значение']) ?>
        </div>
        <div class="col">
            <?= $form->field($model, 'status')->dropDownList(Contract::statusList(), ['prompt' => 'Выберите статус']) ?>
        </div>
    </div>

    <?= $form->field($model, 'is_act_counter_increase_annually')->checkbox() ?>
    <?= $form->field($model, 'subject_address')->textInput(['maxlength' => true]) ?>
    <?= $form->field($model, 'subject_name')->textInput(['maxlength' => true]) ?>
    <?= $form->field($model, 'company_id')->hiddenInput(['value' => $companyId])->label(false) ?>
    <br>
    <p>
        <?= MultipleInput::widget([
            'name' => 'ContractCompany',
            'data' => ContractReadRepository::getContractCompanies($model->id),
            'allowEmptyList' => true,
            'iconSource' => 'fa',
            //'addButtonOptions' => ['class' => 'd-none'],
            //'removeButtonOptions' => ['class' => 'd-none'],
            'attributeOptions' => [
                'enableAjaxValidation' => true,
                'enableClientValidation' => true,
                'validateOnChange' => true,
                'validateOnSubmit' => true,
                'validateOnBlur' => false,
            ],
            'columns' => [
                [
                    'name' => 'company_id',
                    'title' => 'Юридическое лицо',
                    'type' => 'dropDownList',
                    'items' => Company::companiesList(),
                    'options' => [
                        'prompt' => 'Выберите юр.лицо',
                        'options' => ['class' => 'form-control'],
                        'required' => 'required',
                    ],
                ],
                [
                    'name' => 'role',
                    'title' => 'Роль',
                    'type' => 'dropDownList',
                    'items' => ContractCompany::roleList(),
                    'options' => [
                        'prompt' => 'Выберите роль',
                        'options' => ['class' => 'form-control'],
                        'required' => 'required',
                    ],
                ],
                [
                    'name' => 'id',
                    'type' => 'hiddenInput',
                ],
            ],
        ]) ?>
    </p>
    <div class="form-group">
        <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
    </div>
    <?php ActiveForm::end(); ?>
</div>
