<?php

use common\helpers\DateHelper;
use common\helpers\DayHelper;
use kartik\date\DatePicker;
use yii\helpers\Html;
use yii\bootstrap4\ActiveForm;

/** @var yii\web\View $this */
/** @var common\forms\Contract\ContractAmountForm $model */
/** @var common\entities\Contract\Contract $contract */
/** @var yii\bootstrap4\ActiveForm $form */

$js = <<< JS
$(function() {
  $("#isPrepayment").click(enable_cb);
});

function enable_cb() {
  if (this.checked === true) {
    $("#prepaymentPercent").attr("readonly", false);
  } else {
      $("#prepaymentPercent").attr("readonly", true).val('');
  }
}
JS;

$this->registerJs($js, $position = yii\web\View::POS_READY, $key = null);

$this->title = 'Редактирование стоимости и порядка расчетов по договору: ' . $contract->number;
$this->params['breadcrumbs'][] = ['label' => $contract->company->full_name, 'url' => ['company/view', 'id' => $contract->company_id, 'tab' => 'tab_contract']];
$this->params['breadcrumbs'][] = ['label' => 'Договор ' . $contract->number, 'url' => ['view', 'id' => $contract->id]];
$this->params['breadcrumbs'][] = 'Редактирование стоимости и порядка расчетов по договору';
?>

<div class="contract-form">
    <?php $form = ActiveForm::begin(); ?>
    <?= $form->errorSummary($model) ?>
    <?= $form->field($model, 'is_prepayment')->checkbox(['id' => 'isPrepayment']) ?>

    <div class="row g-1">
        <div class="col-auto">
            <?= $form->field($model, 'prepayment_percent')
                ->input('number', ['id' => 'prepaymentPercent', 'readonly' => 'readonly', 'min' => '10', 'max' => '30']) ?>
        </div>
    </div>

    <div class="row g-2">
        <div class="col-auto">
            <?= $form->field($model, 'date_works_start')->widget(DatePicker::class, [
                'language' => 'ru',
                'value' => $model->date_works_start = DateHelper::convert($model->date_works_start, 'date', 'dd.MM.yyyy'),
                'options' => ['placeholder' => 'Выберите дату'],
                'pickerIcon' => '<i class="fa fa-calendar text-primary"></i>',
                'removeIcon' => '<i class="fa fa-trash text-danger"></i>',
                'pluginOptions' => ['autoclose' => true, 'format' => 'dd.mm.yyyy'],
            ]) ?>
        </div>
        <div class="col-auto">
            <?= $form->field($model, 'date_works_end')->widget(DatePicker::class, [
                'language' => 'ru',
                'value' => $model->date_works_end = DateHelper::convert($model->date_works_end, 'date', 'dd.MM.yyyy'),
                'options' => ['placeholder' => 'Выберите дату'],
                'pickerIcon' => '<i class="fa fa-calendar text-primary"></i>',
                'removeIcon' => '<i class="fa fa-trash text-danger"></i>',
                'pluginOptions' => ['autoclose' => true, 'format' => 'dd.mm.yyyy'],
            ]) ?>
        </div>
    </div>

    <div class="row g-2">
        <div class="col-auto">
            <?= $form->field($model, 'report_start_day')->dropDownList(DayHelper::dayList(), ['prompt' => 'Выберите значение']) ?>
        </div>
        <div class="col-auto">
            <?= $form->field($model, 'report_end_day')->dropDownList(DayHelper::dayList(), ['prompt' => 'Выберите значение']) ?>
        </div>
    </div>

    <div class="row g-1">
        <div class="col-auto">
            <?= $form->field($model, 'amount')->textInput() ?>
        </div>
    </div>

    <?= $form->field($model, 'is_nds')->checkbox() ?>

    <div class="form-group">
        <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
        <?= Html::a('Отменить', ['view', 'id' => $contract->id], ['class' => 'btn btn-danger']) ?>
    </div>

    <?php ActiveForm::end(); ?>
</div>
