<?php

use common\helpers\DayHelper;
use common\helpers\DecimalNumberHelper;
use common\widgets\RelatedList;
use yii\bootstrap4\LinkPager;
use yii\bootstrap4\Modal;
use yii\bootstrap4\Tabs;
use yii\data\ActiveDataProvider;
use yii\grid\GridView;
use yii\helpers\Html;
use yii\widgets\DetailView;
use yii\web\YiiAsset;
use yii\widgets\Pjax;

/** @var yii\web\View $this */
/** @var common\entities\Contract\Contract $model */
/** @var ActiveDataProvider $workProvider */
/** @var ActiveDataProvider $expenseProvider */

$this->title = $model->number;
$this->params['breadcrumbs'][] = ['label' => $model->company->full_name, 'url' => ['company/view', 'id' => $model->company_id, 'tab' => 'tab_contract']];
$this->params['breadcrumbs'][] = 'Договор ' . $this->title;
YiiAsset::register($this);
?>
<?php
$this->registerJs(
    '$("body").on("click", ".history-modal", function(e){   
					e.preventDefault();
					$("#viewModal").modal("show").find(".modal-content").load($(this).attr("href"));
				});'
);
Modal::begin(['id' => 'viewModal', 'size' => 'modal-xl']);
Modal::end();

echo Tabs::widget([
    'id' => 'tabs',
    'renderTabContent' => false,
    'linkOptions' => ['data-toggle' => 'tab'],
    'items' => [
        [
            'label' => 'Общая информация',
            'options' => ['id' => 'tab_main'],
            'active' => true,
        ],
        [
            'label' => 'Роли в договоре',
            'options' => ['id' => 'tab_role'],
        ],
        [
            'label' => 'Стоимость и порядок расчета',
            'options' => ['id' => 'tab_amount'],
        ],
        [
            'label' => 'Сроки выполнения работ',
            'options' => ['id' => 'tab_work'],
        ],
        [
            'label' => 'Связанные расходы',
            'options' => ['id' => 'tab_expense'],
        ],
    ],
]);
?>
<div class="tab-content">
    <div class="tab-pane active" id="tab_main">
        <hr>
        <div class="contract-view">
            <p>
                <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Смета', ['contract-estimate/index', 'contractId' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Проектная документация', [
                        'project/index', 'contractId' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
                    'class' => 'btn btn-danger',
                    'data' => [
                        'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                        'method' => 'post',
                    ],
                ]) ?>
            </p>

            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    'number',
                    'date_start:date',
                    [
                        'attribute' => 'subject_address',
                        'visible' => !empty($model->subject_address),
                    ],
                    [
                        'attribute' => 'subject_name',
                        'visible' => !empty($model->subject_name),
                    ],
                    [
                        'attribute' => 'is_act_counter_increase_annually',
                        'value' => function ($model) {
                            return $model->is_act_counter_increase_annually === 0 ? 'Нет' : 'Да';
                        },
                    ],
                    [
                        'attribute' => 'documents_day_end',
                        'value' => function ($model) {
                            return DayHelper::isLastDay($model->documents_day_end);
                        },
                    ],
                    [
                        'attribute' => 'status',
                        'value' => function ($model) {
                            return $model->statusName;
                        },
                    ],
                    'created_at:datetime',
                    'updated_at:datetime',
                ],
            ]) ?>
        </div>
    </div>

    <div class="tab-pane" id="tab_role">
        <hr>
        <div class="contract-view">
            <p>
                <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
            </p>
            <?= RelatedList::widget([
                'models' => $model->contractCompanies,
                'attributes' => [
                    'company_id',
                    'role',
                ],
                'values' => [
                    'company' => 'full_name',
                    'roleName' => 'roleName',
                ],
            ]);
?>
        </div>
    </div>

    <div class="tab-pane" id="tab_amount">
        <hr>
        <div class="contract-view">
            <p>
                <?= Html::a(
                    'Редактировать',
                    [
                        'update-amount',
                        'id' => $model->id,
                    ],
                    [
                        'class' => 'btn btn-primary',
                    ]
                ) ?>
                <?= Html::a(
                    'История изменений',
                    [
                        'contract/history',
                        'HistoryQuery[row_id]' => $model->id,
                    ],
                    [
                        'class' => 'history-modal btn btn-primary',
                    ]
                ); ?>
            </p>
            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    [
                        'attribute' => 'is_prepayment',
                        'value' => function ($model) {
                            return $model->is_prepayment === 0 ? 'Нет' : 'Да';
                        },
                        'visible' => !empty($model->amount),
                    ],
                    [
                        'attribute' => 'prepayment_percent',
                        'value' => function ($model) {
                            return $model->prepayment_percent . '%';
                        },
                        'visible' => !empty($model->prepayment_percent),
                    ],
                    'date_works_start:date',
                    'date_works_end:date',
                    [
                        'attribute' => 'report_start_day',
                        'value' => function ($model) {
                            return DayHelper::isLastDay($model->report_start_day);
                        },
                    ],
                    [
                        'attribute' => 'report_end_day',
                        'value' => function ($model) {
                            return DayHelper::isLastDay($model->report_end_day);
                        },
                    ],
                    [
                        'attribute' => 'amount',
                        'value' => function ($model) {
                            $value = DecimalNumberHelper::numFormat($model->amount);
                            if ($model->is_nds === 0) {
                                return $value . ' (без НДС)';
                            } else {
                                return $value . ' (с НДС)';
                            }
                        },
                    ],
                ],
            ]) ?>
        </div>
    </div>
    <div class="tab-pane" id="tab_work">
        <hr>
        <div class="contract-work-view">
            <p>
                <?= Html::a('Добавить', ['contract-work/create', 'contractId' => $model->id], ['class' => 'btn btn-primary']) ?>
            </p>
            <?php Pjax::begin(); ?>
            <?= GridView::widget([
                'dataProvider' => $workProvider,
                'tableOptions' => ['class' => 'table table-bordered table-hover'],
                'pager' => ['class' => LinkPager::class],
                'columns' => [
                    'id',
                    [
                        'attribute' => 'work_type_id',
                        'value' => function ($model) {
                            return $model->workType->name;
                        },
                    ],
                    'date_start:date',
                    'date_end:date',
                    [
                        'label' => 'Признак редактирования',
                        'value' => function ($model) {
                            if ($model->history) {
                                return Html::a('Да', ['contract-work/history', 'HistoryQuery[row_id]' => $model->id], ['class' => 'history-modal']);
                            } else {
                                return 'Нет';
                            }
                        },
                        'format' => 'raw',
                    ],
                    ['class' => 'yii\grid\ActionColumn',
                        'header' => 'Опции',
                        'template' => '{view} {update} ',
                        'urlCreator' => function ($action, $model) {
                            if ($action === 'view') {
                                return ['contract-work/view', 'id' => $model->id];
                            }
                            if ($action === 'update') {
                                return ['contract-work/update', 'id' => $model->id];
                            }
                        },
                    ],
                ],
            ]); ?>
            <?php Pjax::end(); ?>
        </div>
    </div>
    <div class="tab-pane" id="tab_expense">
        <hr>
        <div class="contract-expense-view">
            <p>
                <?= Html::a('Добавить', ['contract-expense/create', 'contractId' => $model->id], ['class' => 'btn btn-primary']) ?>
            </p>
            <?php Pjax::begin(); ?>
            <?= GridView::widget([
                'dataProvider' => $expenseProvider,
                'tableOptions' => ['class' => 'table table-bordered table-hover'],
                'pager' => ['class' => LinkPager::class],
                'columns' => [
                    'id',
                    [
                        'attribute' => 'expense_type',
                        'value' => function ($expenseProvider) {
                            return $expenseProvider->typeName;
                        },
                    ],
                    [
                        'label' => 'Сумма с НДС',
                        'value' => function ($model) {
                            if ($model->is_nds === 0) {
                                return DecimalNumberHelper::numFormat($model->addNds());
                            } else {
                                return DecimalNumberHelper::numFormat($model->amount);
                            }
                        },
                    ],
                    [
                        'label' => 'Сумма без НДС',
                        'value' => function ($model) {
                            if ($model->is_nds === 0) {
                                return DecimalNumberHelper::numFormat($model->amount);
                            } else {
                                return DecimalNumberHelper::numFormat($model->removeNds());
                            }
                        },
                    ],
                    [
                        'attribute' => 'contractor_id',
                        'value' => function ($expenseProvider) {
                            return $expenseProvider->contractor->company->full_name;
                        },
                    ],
                    [
                        'label' => 'Признак редактирования',
                        'value' => function ($model) {
                            if ($model->history) {
                                return Html::a('Да', ['contract-expense/history', 'HistoryQuery[row_id]' => $model->id], ['class' => 'history-modal']);
                            } else {
                                return 'Нет';
                            }
                        },
                        'format' => 'raw',
                    ],
                    ['class' => 'yii\grid\ActionColumn',
                        'header' => 'Опции',
                        'template' => '{view} {update} ',
                        'urlCreator' => function ($action, $expenseProvider) {
                            if ($action === 'view') {
                                return ['contract-expense/view', 'id' => $expenseProvider->id];
                            }
                            if ($action === 'update') {
                                return ['contract-expense/update', 'id' => $expenseProvider->id];
                            }
                        },
                    ],
                ],
            ]); ?>
            <?php Pjax::end(); ?>
        </div>
    </div>
</div>
