<?php

/** @var View $this */

/** @var string $content */

use backend\assets\AppAsset;
use common\widgets\AlertFlash;
use yii\helpers\Html;
use yii\bootstrap4\Nav;
use yii\bootstrap4\NavBar;
use yii\web\View;
use yii\bootstrap4\Breadcrumbs;

AppAsset::register($this);
?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="<?= Yii::$app->language ?>">
<head>
    <meta charset="<?= Yii::$app->charset ?>">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <?php $this->registerCsrfMetaTags() ?>
    <title><?= Html::encode($this->title) ?></title>
    <?php $this->head() ?>
</head>
<body>
<?php $this->beginBody() ?>

<div class="wrap">
    <?php
    NavBar::begin([
        'brandLabel' => Yii::$app->name,
        'brandUrl' => Yii::$app->homeUrl,
        'options' => [
            'class' => 'fixed-top navbar-expand-lg navbar-dark bg-dark',
        ],
    ]);
    $menuItems = [
        //['label' => 'Главная', 'url' => ['/site/index'], 'options' => ['class' => 'btn']],
        ['label' => 'Юридические лица', 'url' => ['/company/index'], 'options' => ['class' => 'btn']],
        ['label' => 'Клиенты', 'url' => ['/company/clients'], 'options' => ['class' => 'btn']],
        [
            'label' => 'Справочники',
            'url' => ['#'],
            'options' => ['class' => 'btn'],
            'items' => [
                ['label' => 'Единицы измерения', 'url' => ['/unit-measure/index'], 'options' => ['class' => 'btn']],
                ['label' => 'Типы работ', 'url' => ['/work-type/index'], 'options' => ['class' => 'btn']],
                ['label' => 'Перечень работ', 'url' => ['/work-list/index'], 'options' => ['class' => 'btn']],
                ['label' => 'Нормы расходов', 'url' => ['/consumption-rate/index'], 'options' => ['class' => 'btn']],
            ],
        ],
    ];
    if (Yii::$app->user->isGuest) {
        $menuItems[] = ['label' => 'Вход', 'url' => ['/auth/login']];
    } else {
        $menuItems[] = [
            'label' => 'Выход',
            'url' => ['/auth/logout'],
            'linkOptions' => [
                'id' => 'logout',
                'data-method' => 'post',
            ],
            'options' => ['class' => 'btn'],
        ];
    }
    echo Nav::widget([
        'options' => ['class' => 'navbar-nav ml-auto'],
        'items' => $menuItems,
    ]);
    NavBar::end();
    ?>

    <div class="container">
        <?= Breadcrumbs::widget([
            'links' => $this->params['breadcrumbs'] ?? [],
        ]) ?>
        <?= AlertFlash::widget() ?>
        <?= $content ?>
    </div>
</div>

<footer class="footer">
    <div class="container">
        <p class="pull-left">&copy; <?= Html::encode(Yii::$app->name) ?> <?= date('Y') ?></p>
    </div>
</footer>

<?php $this->endBody() ?>
</body>
</html>
<?php $this->endPage() ?>
