<?php

/** @var ProjectImage $model */

/** @var int $contractId */

use common\entities\Project\ProjectImage;
use common\helpers\ProjectHelper;
use common\helpers\ProjectImageHelper;
use unclead\multipleinput\MultipleInput;
use yii\helpers\Html;
use yii\bootstrap4\ActiveForm;
use yii\helpers\Url;

$this->title = 'Присвоение изображениям тип работы';
?>
<p>
    <?= Html::a('Добавить тип работы', ['work-type/create'], ['class' => 'btn btn-primary']) ?>
</p>

<?php ActiveForm::begin(['id' => 'project-image-type']) ?>

<div class="row g-1">
    <div class="col">
        <?= MultipleInput::widget([
            'name' => 'ProjectImage',
            'data' => $model->getImages($contractId),
            'allowEmptyList' => true,
            'iconSource' => 'fa',
            'addButtonOptions' => ['class' => 'd-none'],
            'removeButtonOptions' => ['class' => 'd-none'],
            'attributeOptions' => [
                'enableAjaxValidation' => false,
                'enableClientValidation' => false,
                'validateOnChange' => false,
                'validateOnSubmit' => false,
                'validateOnBlur' => false,
            ],
            'columns' => [
                [
                    'name' => 'pdf_name',
                    'title' => 'Файл PDF',
                    'type' => 'static',
                    'value' => function ($data) {
                        return ProjectHelper::getFileName(ProjectHelper::getPdfSourcePath() . '/' . $data->pdf_name);
                    },
                ],
                [
                    'name' => 'name',
                    'title' => 'Страница',
                    'type' => 'static',
                    'value' => function ($data) {
                        $image = ProjectHelper::getImageSourcePath($data->pdf_name) . '/' . $data->name;
                        if (file_exists($image)) {
                            return Html::a(
                                ProjectHelper::getFileName($image),
                                ['project/show-image', 'id' => $data->id],
                                ['class' => 'file-modal', 'target' => '_blank'],
                            );
                        }

                        return ProjectHelper::getFileName($image);
                    },
                ],
                [
                    'name' => 'work_type_id',
                    'title' => 'Тип работы',
                    'type' => 'dropDownList',
                    'items' => ProjectImageHelper::imageWorkList(),
                    'options' => [
                        'prompt' => 'Выберите тип работы',
                        'options' => ['class' => 'form-control'],
                        'required' => 'required',
                    ],
                ],
                [
                    'name' => 'stage',
                    'title' => 'Этаж',
                    'type' => 'textInput',
                    'options' => [
                        'type' => 'number',
                        'min' => 0,
                        'max' => 999,
                    ],
                ],
                [
                    'name' => 'id',
                    'type' => 'hiddenInput',
                ],
            ],
        ]) ?>
    </div>
</div>

<hr>

<div class="form-group">
    <?= Html::submitButton('Сохранить', ['class' => 'btn btn-primary']) ?>
    <?= Html::a('Отменить', ['index', 'contractId' => $contractId], ['class' => 'btn btn-danger']) ?>
</div>

<?php ActiveForm::end() ?>
