<?php

use yii\bootstrap4\LinkPager;
use yii\helpers\Html;
use yii\grid\GridView;
use yii\helpers\Url;

/** @var yii\web\View $this */
/** @var yii\data\ActiveDataProvider $dataProvider */
/** @var int $contractId */

$this->title = 'Проектная документация';
$this->params['breadcrumbs'][] = ['label' => 'Договор', 'url' => ['contract/view', 'id' => $contractId]];
$this->params['breadcrumbs'][] = $this->title;

?>

<div class="project-index">
    <p>
        <?= Html::a('Добавить PDF', ['project/upload-pdf', 'contractId' => $contractId], ['class' => 'btn btn-primary']) ?>
        <?= Html::a('Страницы', ['project/image-work-type', 'contractId' => $contractId], ['class' => 'btn btn-primary']) ?>
    </p>

    <?= GridView::widget([
        'dataProvider' => $dataProvider,
        'tableOptions' => ['class' => 'table table-bordered table-hover'],
        'pager' => ['class' => LinkPager::class],
        'columns' => [
            [
                'attribute' => 'work_type_id',
                'value' => function ($model) {
                    return $model->workType->name;
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'label' => 'Количество страниц',
                'value' => function ($model) {
                    return count($model->images);
                },
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'label' => 'Связок со сметными строками',
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'label' => 'Связок с нормативными строками',
                'headerOptions' => ['class' => 'text-wrap'],
            ],
            [
                'attribute' => 'contractor_id',
                'value' => function ($model) {
                    if ($model->contractor_id) {
                        return Html::a(Html::encode($model->contractor->company->full_name), Url::to(['project/contractor-update', 'id' => $model->id]));
                    }

                    return Html::a('Редактировать', Url::to(['project/contractor-update', 'id' => $model->id]));
                },
                'headerOptions' => ['class' => 'text-wrap'],
                'format' => 'raw',
            ],
            ['class' => 'yii\grid\ActionColumn',
                'header' => 'Страницы',
                'template' => '{pages}',
                'buttons' => [
                    'pages' => function ($action, $model) {
                        return Html::a(
                            '<span class="fa fa-star"></span>',
                            Url::to(['project/pages', 'contractId' => $model->contract_id, 'workTypeId' => $model->work_type_id]),
                            ['title' => 'Страницы']
                        );
                    },
                ],
            ],
        ],
    ]); ?>
</div>
