<?php

use common\widgets\RelatedList;
use yii\bootstrap4\Tabs;
use yii\helpers\Html;
use yii\widgets\DetailView;
use yii\web\YiiAsset;

/** @var yii\web\View $this */
/** @var common\entities\Dictionaries\WorkList $model */

$this->title = $model->name;
$this->params['breadcrumbs'][] = ['label' => 'Перечень работ', 'url' => ['index']];
$this->params['breadcrumbs'][] = $this->title;
YiiAsset::register($this);
?>
<?php
echo Tabs::widget([
    'id' => 'tabs',
    'renderTabContent' => false, // If each tab is displayed, it is custom DIV perhaps Render Other page files , Set as false.
    'linkOptions' => ['data-toggle' => 'tab'],
    'items' => [
        [
            'label' => 'Общая информация',
            'options' => ['id' => 'tab_main'],
            'active' => true,
        ],
        [
            'label' => 'Материалы',
            'options' => ['id' => 'tab_material'],
            'visible' => !empty($model->workListsMaterials),
        ],
    ],
]);
?>
<div class="tab-content">
    <div class="tab-pane active" id="tab_main">
        <hr>
        <div class="work-list-view">
            <p>
                <?= Html::a('Редактировать', ['update', 'id' => $model->id], ['class' => 'btn btn-primary']) ?>
                <?= Html::a('Удалить', ['delete', 'id' => $model->id], [
                    'class' => 'btn btn-danger',
                    'data' => [
                        'confirm' => 'Вы уверены, что хотите удалить эту запись?',
                        'method' => 'post',
                    ],
                ]) ?>
            </p>

            <?= DetailView::widget([
                'model' => $model,
                'attributes' => [
                    'id',
                    'name',
                    'alias',
                    'description',
                    [
                        'attribute' => 'unit_measure_id',
                        'value' => function ($model) {
                            return $model->unitMeasure->alias;
                        },
                        'format' => 'raw',
                    ],
                    [
                        'attribute' => 'work_type_id',
                        'value' => function ($model) {
                            return $model->workType->name;
                        },
                        'format' => 'raw',
                    ],
                    'created_at:datetime',
                    'updated_at:datetime',
                ],
            ]) ?>
        </div>
    </div>

    <div class="tab-pane" id="tab_material">
        <hr>
        <div class="work-list-material-view">
            <?= RelatedList::widget([
                'models' => $model->workListsMaterials,
                'attributes' => [
                    'name',
                    'unit_measure_id',
                ],
                'values' => [
                    'name' => 'name',
                    'unitMeasure' => 'alias',
                ],
            ]);
?>
        </div>
    </div>
</div>
