<?php

namespace common\auth;

use common\entities\User\User;
use common\readModels\UserReadRepository;
use Yii;
use yii\base\InvalidConfigException;
use yii\di\NotInstantiableException;
use yii\web\IdentityInterface;

class Identity implements IdentityInterface
{
    private User $user;

    public function __construct(User $user)
    {
        $this->user = $user;
    }

    /**
     * @throws NotInstantiableException
     * @throws InvalidConfigException
     * @param string|int $id
     */
    public static function findIdentity($id): ?Identity
    {
        $user = self::getRepository()->findActiveById($id);
        return $user ? new self($user) : null;
    }

    public function getId(): int
    {
        return $this->user->getPrimaryKey();
    }

    public function getAuthKey(): string
    {
        return $this->user->auth_key;
    }

    /**
     * @param string|null $authKey
     * @return bool|null
     */
    public function validateAuthKey($authKey): bool
    {
        return $this->getAuthKey() === $authKey;
    }

    /**
     * @throws NotInstantiableException
     * @throws InvalidConfigException
     */
    public function checkUserCredentials(string $username, string $password): bool
    {
        if (!$user = self::getRepository()->findActiveByUsername($username)) {
            return false;
        }
        return $user->validatePassword($password);
    }

    /**
     * @throws NotInstantiableException
     * @throws InvalidConfigException
     */
    public function getUserDetails(string $username): array
    {
        $user = self::getRepository()->findActiveByUsername($username);
        return ['user_id' => $user->id];
    }

    /**
     * @throws NotInstantiableException
     * @throws InvalidConfigException
     * @param mixed $token
     * @param mixed $type
     */
    public static function findIdentityByAccessToken($token, $type = null): ?User
    {
        return self::getRepository()->findByAccessToken($token);
    }

    /**
     * При обращении к свойствам сущности user
     * @return mixed
     */
    public function __get(string $name)
    {
        return $this->user->$name;
    }

    /**
     * При обращении к методам сущности user
     * @return mixed
     */
    public function __call(string $methodName, string $args)
    {
        return $this->user->$methodName($args);
    }

    /**
     * @throws NotInstantiableException
     * @throws InvalidConfigException
     */
    private static function getRepository(): UserReadRepository
    {
        return Yii::$container->get(UserReadRepository::class);
    }
}
