<?php

namespace common\components\gii\generators\controller;

use common\components\api\rest\controllers\ActiveController;
use Yii;
use yii\db\ActiveRecord;
use yii\gii\CodeFile;
use yii\helpers\StringHelper;

/**
 * This generator will generate a controller.
 *
 * @property string $controllerFile The controller class file path. This property is read-only.
 * @property string $controllerID The controller ID. This property is read-only.
 * @property string $controllerNamespace The namespace of the controller class. This property is read-only.
 * @property string $controllerSubPath The controller sub path. This property is read-only.
 *
 */
class Generator extends \yii\gii\generators\controller\Generator
{
    /** @var  string список действий для которых будет создана документация */
    public $actions = ['index' => 'index'];

    /**@inheritdoc */
    public $baseClass = ActiveController::class;

    /**@var string  модель для контролера */
    public $modelClass;

    /**
     * @inheritdoc
     */
    public function getName()
    {
        return ' API Controller Generator';
    }

    /**
     * @inheritdoc
     */
    public function getDescription()
    {
        return 'Генератор API  контроллеров основанных на библиотеке REST API';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['controllerClass', 'baseClass', 'modelClass'], 'filter', 'filter' => 'trim'],
            [['controllerClass', 'baseClass', 'modelClass', 'actions'], 'required'],
            ['controllerClass', 'match', 'pattern' => '/^[\w\\\\]*Controller$/', 'message' => 'Only word characters and backslashes are allowed, and the class name must end with "Controller".'],
            ['controllerClass', 'validateNewClass'],
            [['modelClass'], 'validateModelClass'],
            ['baseClass', 'match', 'pattern' => '/^[\w\\\\]*$/', 'message' => 'Only word characters and backslashes are allowed.'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return array_merge(parent::attributeLabels(), [
            'actions'    => 'Actions',
            'modelClass' => 'Model Class',
        ]);
    }

    /**
     * @inheritdoc
     */
    public function hints()
    {
        return array_merge(parent::hints(), [
            'modelClass' => 'This is the ActiveRecord class associated with the table that CRUD will be built upon.
                You should provide a fully qualified class name, e.g., <code>app\models\Post</code>.',
            'actions'    => 'Список действий для генерации документации',
        ]);
    }

    /**
     * @inheritdoc
     */
    public function generate()
    {
        $files = [];

        $files[] = new CodeFile(
            $this->getControllerFile(),
            $this->render('controller.php')
        );
        $files[] = new CodeFile(
            $this->getDocsFile(),
            $this->render('docs.php')
        );

        return $files;
    }

    /**
     * Checks if model class is valid
     */
    public function validateModelClass()
    {
        /* @var $class ActiveRecord */
        $class = $this->modelClass;
        $pk = $class::primaryKey();
        if (empty($pk)) {
            $this->addError('modelClass', "The table associated with $class must have primary key(s).");
        }
    }

    /**
     * Метод возвращает название модели.
     * @return string
     */
    public function getModelName()
    {
        return StringHelper::basename($this->modelClass);
    }

    /**
     * @return string путь до файла с документацией
     */
    public function getDocsFile()
    {
        return Yii::getAlias('@swagger/docs/controllers/' . $this->getControllerID()) . '.php';
    }

    /**
     * Метод возвращает код для
    */
    public function getSecurityCode(){
        return 'security={{"auth_token":{}}},';
    }
}
