<?php

namespace common\entities\Company;

use yii\helpers\ArrayHelper;
use Exception;

class CompanyTypeDictionary
{
    public const TYPE_IP = 10;
    public const TYPE_PT = 20;
    public const TYPE_KT = 30;
    public const TYPE_PK = 40;
    public const TYPE_OOO = 50;
    public const TYPE_ODO = 60;
    public const TYPE_ZAO = 70;
    public const TYPE_OAO = 80;
    public const TYPE_PAO = 90;

    /**
     * Получение полного значения типа организации
     * @throws Exception
     */
    public static function fullTypeName(int $type): string
    {
        return ArrayHelper::getValue(self::allTypesWithFullLabels(), $type);
    }

    /**
     * Получение полное значения типа организации
     * @throws Exception
     */
    public static function shortTypeName(int $type): string
    {
        return ArrayHelper::getValue(self::allTypesWithShortLabels(), $type);
    }

    /**
     * Возвращает ключи всех типов с сокращенными наименованиями.
     * @return array
     */
    public static function allShortTypes(): array
    {
        return array_keys(static::allTypesWithShortLabels());
    }

    /**
     * Возвращает ключи всех типов с полными наименованиями.
     * @return array
     */
    public static function allFullTypes(): array
    {
        return array_keys(static::allTypesWithFullLabels());
    }

    /**
     * Возвращает список всех типов с сокращенными наименованиями.
     * @return array
     */
    public static function allTypesWithShortLabels(): array
    {
        return [
            self::TYPE_IP => 'ИП',
            self::TYPE_PT => 'ПТ',
            self::TYPE_KT => 'КТ',
            self::TYPE_PK => 'ПК',
            self::TYPE_OOO => 'ООО',
            self::TYPE_ODO => 'ОДО',
            self::TYPE_ZAO => 'ЗАО',
            self::TYPE_OAO => 'ОАО',
            self::TYPE_PAO => 'ПАО',
        ];
    }

    /**
     * Возвращает список всех типов с полными наименованиями.
     * @return array
     */
    public static function allTypesWithFullLabels(): array
    {
        return [
            self::TYPE_IP => 'Индивидуальный предприниматель',
            self::TYPE_PT => 'Полное товарищество',
            self::TYPE_KT => 'Коммандитное товарищество',
            self::TYPE_PK => 'Производственный кооператив',
            self::TYPE_OOO => 'Общество с ограниченной ответственностью',
            self::TYPE_ODO => 'Общество с дополнительной ответственностью',
            self::TYPE_ZAO => 'Закрытое акционерное общество',
            self::TYPE_OAO => 'Открытое акционерное общество',
            self::TYPE_PAO => 'Публичное акционерное общество',
        ];
    }
}
