<?php

namespace common\entities\Contract;

use common\entities\Company\Company;
use Exception;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "{{%contract_companies}}".
 *
 * @property int $id
 * @property int $contract_id Запись договора
 * @property int $company_id Запись юридического лица
 * @property int $role Роль в контракте
 *
 * @property Contract $contract
 * @property Company $company
 */
class ContractCompany extends ActiveRecord
{
    public const ROLE_CUSTOMER = 10;
    public const ROLE_GENERAL_CONTRACTOR = 20;
    public const ROLE_DESIGNER = 30;
    public const ROLE_CONTRACTOR = 40;

    public static function tableName(): string
    {
        return '{{%contract_companies}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['contract_id', 'company_id', 'role'], 'required'],
            [['contract_id', 'company_id', 'role'], 'integer'],
            [['contract_id'], 'exist', 'skipOnError' => true, 'targetClass' => Contract::class, 'targetAttribute' => ['contract_id' => 'id']],
            [['company_id'], 'exist', 'skipOnError' => true, 'targetClass' => Company::class, 'targetAttribute' => ['company_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'contract_id' => 'Запись договора',
            'company_id' => 'Запись юридического лица',
            'role' => 'Роль в договоре',
        ];
    }

    /**
     * Возвращает массив ролей по договору.
     */
    public static function roleList(): array
    {
        return [
            ContractCompany::ROLE_CUSTOMER => 'Заказчик',
            ContractCompany::ROLE_GENERAL_CONTRACTOR => 'Генподрядчик',
            ContractCompany::ROLE_DESIGNER => 'Проектировщик',
            ContractCompany::ROLE_CONTRACTOR => 'Подрядчик',
        ];
    }

    /**
     * Получение значения роли юрлица.
     *
     * @throws Exception
     */
    public function getRoleName(): string
    {
        return ArrayHelper::getValue(self::roleList(), $this->role);
    }

    /**
     * Создание/Редактирование записи.
     */
    public function create(int $company_id, int $role, int $contract_id): void
    {
        $this->company_id = $company_id;
        $this->role = $role;
        $this->contract_id = $contract_id;
    }

    /**
     * Gets query for [[Contract]].
     */
    public function getContract(): ActiveQuery
    {
        return $this->hasOne(Contract::class, ['id' => 'contract_id']);
    }

    /**
     * Gets query for [[Company]].
     */
    public function getCompany(): ActiveQuery
    {
        return $this->hasOne(Company::class, ['id' => 'company_id']);
    }

    /**
     * Возвращает массив юридических лиц по договору.
     * Массив содержит ID и полное наименование.
     */
    public static function companiesList($id): array
    {
        $arr = [];
        foreach (self::findAll(['contract_id' => $id]) as $contractCompany) {
            $arr[$contractCompany->company_id] = $contractCompany->company->full_name;
        }

        return $arr;
    }
}
