<?php

namespace common\entities\Contract;

use common\entities\Dictionaries\WorkType;
use common\helpers\DateHelper;
use common\modules\entitiesHistory\behaviors\HistoryBehavior;
use common\modules\entitiesHistory\entities\History;
use ReflectionClass;
use yii\base\InvalidConfigException;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "{{%contract_works}}".
 *
 * @property int $id
 * @property int $contract_id Запись договора
 * @property int $work_type_id Тип работы
 * @property string $date_start Дата начала работы
 * @property string $date_end Дата окончания работы
 *
 * @property Contract $contract
 * @property WorkType $workType
 */
class ContractWork extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%contract_works}}';
    }

    /** @throws InvalidConfigException */
    public function beforeSave($insert): bool
    {
        if (parent::beforeSave($insert)) {
            $this->date_start = DateHelper::convert($this->date_start);
            $this->date_end = DateHelper::convert($this->date_end);

            return true;
        }

        return false;
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['contract_id', 'work_type_id', 'date_start', 'date_end'], 'required'],
            [['contract_id', 'work_type_id'], 'integer'],
            [['date_start', 'date_end'], 'string'],
            ['date_end', 'validateDateEnd'],
            [['contract_id'], 'exist', 'skipOnError' => true, 'targetClass' => Contract::class, 'targetAttribute' => ['contract_id' => 'id']],
            [['work_type_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkType::class, 'targetAttribute' => ['work_type_id' => 'id']],
        ];
    }

    public function validateDateEnd($attribute)
    {
        if (strtotime($this->date_end) < strtotime($this->date_start)) {
            $this->addError($attribute, 'Дата окончания работы не может быть меньше даты начала работы');
        }
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'contract_id' => 'Запись договора',
            'work_type_id' => 'Тип работы',
            'date_start' => 'Дата начала работы',
            'date_end' => 'Дата окончания работы',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            'History' => [
                'class' => HistoryBehavior::class,
                'allowEvents' => [
                    //HistoryBehavior::EVENT_INSERT,
                    HistoryBehavior::EVENT_UPDATE,
                    //HistoryBehavior::EVENT_DELETE,
                ],
                'skipAttributes' => [
                    'work_type_id',
                ],
            ],
        ];
    }

    /**
     * Gets query for [[Contract]].
     */
    public function getContract(): ActiveQuery
    {
        return $this->hasOne(Contract::class, ['id' => 'contract_id']);
    }

    /**
     * Gets query for [[WorkType]].
     */
    public function getWorkType(): ActiveQuery
    {
        return $this->hasOne(WorkType::class, ['id' => 'work_type_id']);
    }

    public function getHistory(): ActiveQuery
    {
        return History::find()->where(['model_name' => (new ReflectionClass($this))->name, 'row_id' => $this->id]);
    }
}
