<?php

namespace common\entities\Dictionaries;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "consumption_rates".
 *
 * @property int $id
 * @property int $work_list_id Запись перечня работ
 * @property int $work_scope Планируемый объем работ
 * @property int $work_unit_cost Стоимость за единицу работы
 * @property int $created_at Дата создания
 * @property int $updated_at Дата обновления
 *
 * @property ConsumptionRatesMaterial[] $consumptionRateMaterials
 * @property WorkList $workList
 */
class ConsumptionRate extends ActiveRecord
{
    /**
     * Создание записи.
     */
    public static function create(int $work_list_id, float $work_unit_cost, float $work_scope): self
    {
        $rate = new static();
        $rate->work_list_id = $work_list_id;
        $rate->work_scope = $work_unit_cost;
        $rate->work_unit_cost = $work_scope;

        return $rate;
    }

    public static function tableName(): string
    {
        return '{{%consumption_rates}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['work_list_id', 'work_unit_cost', 'work_scope'], 'required'],
            [['work_list_id', 'created_at', 'updated_at'], 'integer'],
            [['work_unit_cost', 'work_scope'], 'number', 'min' => 0],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'work_list_id' => 'Запись перечня работ',
            'work_scope' => 'Планируемый объем работ',
            'work_unit_cost' => 'Стоимость за единицу работы',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            TimestampBehavior::class,
        ];
    }

    /**
     * Редактирование записи.
     */
    public function edit(int $work_list_id, float $work_unit_cost, float $work_scope): void
    {
        $this->work_list_id = $work_list_id;
        $this->work_scope = $work_unit_cost;
        $this->work_unit_cost = $work_scope;
    }

    /**
     * Получение всех записей материалов к норме расходов
     */
    public function getConsumptionRateMaterials(): ActiveQuery
    {
        return $this->hasMany(ConsumptionRatesMaterial::class, ['consumption_rate_id' => 'id'])->orderBy('sort');
    }

    /**
     * Получение всех записей работ к норме расходов.
     */
    public function getWorkList(): ActiveQuery
    {
        return $this->hasOne(WorkList::class, ['id' => 'work_list_id']);
    }

    /**
     * Стоимость работы.
     */
    public function workAmount(): float
    {
        return $this->work_scope * $this->work_unit_cost;
    }

    /**
     * Стоимость материалов.
     */
    public function materialsAmount(): float
    {
        $amount = 0;
        if ($materials = $this->consumptionRateMaterials) {
            foreach ($materials as $material) {
                $amount += $material->material_expense * $material->material_unit_cost;
            }
        }

        return $amount;
    }

    /**
     * Общая стоимость.
     */
    public function amount(): float
    {
        return $this->workAmount() + $this->materialsAmount();
    }
}
