<?php

namespace common\entities\Dictionaries;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "consumption_rates_materials".
 *
 * @property int $id
 * @property int $consumption_rate_id Запись нормы расхода
 * @property int $material_id Запись материала из перечня работ
 * @property float $material_expense Расход материала
 * @property float $material_unit_cost Стоимость за единицу материала
 * @property int $sort Сортировка
 * @property int $created_at Дата создания
 * @property int $updated_at Дата обновления
 *
 * @property ConsumptionRate $consumptionRate
 * @property WorkListsMaterial $workListsMaterial
 */
class ConsumptionRatesMaterial extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%consumption_rates_materials}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['consumption_rate_id', 'material_id'], 'required'],
            [['consumption_rate_id', 'material_id', 'sort', 'created_at', 'updated_at'], 'integer'],
            [['material_expense', 'material_unit_cost'], 'number', 'min' => 0],
            [
                ['consumption_rate_id'],
                'exist',
                'skipOnError' => true,
                'targetClass' => ConsumptionRate::class,
                'targetAttribute' => ['consumption_rate_id' => 'id'],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'consumption_rate_id' => 'Запись нормы расхода',
            'material_id' => 'Материал',
            'material_expense' => 'Расход материала',
            'material_unit_cost' => 'Стоимость за единицу материала',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            TimestampBehavior::class,
        ];
    }

    /**
     * Создание/Редактирование записи.
     */
    public function create(
        int $consumption_rate_id,
        int $material_id,
        ?float $material_expense = null,
        ?float $material_unit_cost = null,
        ?int $sort = 1
    ): void {
        $this->consumption_rate_id = $consumption_rate_id;
        $this->material_id = $material_id;
        $this->material_expense = $material_expense;
        $this->material_unit_cost = $material_unit_cost;
        $this->sort = $sort;
    }

    /**
     * Gets query for [[ConsumptionRate]].
     */
    public function getConsumptionRate(): ActiveQuery
    {
        return $this->hasOne(ConsumptionRate::class, ['id' => 'consumption_rate_id']);
    }

    /**
     * Gets query for [[WorkListMaterial]].
     */
    public function getWorkListsMaterial(): ActiveQuery
    {
        return $this->hasOne(WorkListsMaterial::class, ['id' => 'material_id']);
    }
}
