<?php

namespace common\entities\Dictionaries;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "work_lists".
 *
 * @property int $id
 * @property string $name Наименование
 * @property string $alias Сокращение
 * @property string $description Описание
 * @property int $work_type_id Запись типа работ
 * @property int $unit_measure_id Запись единицы измерения
 * @property int $created_at Дата создания
 * @property int $updated_at Дата обновления
 *
 * @property WorkListsMaterial[] $workListsMaterials
 * @property UnitMeasure $unitMeasure
 * @property WorkType $workType
 */
class WorkList extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%work_lists}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['name', 'alias', 'description', 'unit_measure_id', 'work_type_id'], 'required'],
            [['unit_measure_id', 'work_type_id', 'created_at', 'updated_at'], 'integer'],
            [['name'], 'string', 'max' => 255],
            [['alias'], 'string', 'max' => 128],
            [['description'], 'string', 'max' => 512],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'name' => 'Наименование',
            'alias' => 'Сокращение',
            'description' => 'Описание',
            'work_type_id' => 'Тип работы',
            'unit_measure_id' => 'Единица измерения работы',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            TimestampBehavior::class,
        ];
    }

    /**
     * Массив типов работ по ID и сокращению.
     */
    public static function workList(): array
    {
        return ArrayHelper::map(self::find()->all(), 'id', 'name');
    }

    /**
     * Gets query for [[WorkListsMaterials]].
     */
    public function getWorkListsMaterials(): ActiveQuery
    {
        return $this->hasMany(WorkListsMaterial::class, ['work_list_id' => 'id'])->orderBy('sort');
    }

    /**
     * Gets query for [[WorkListsMaterials]].
     */
    public function getUnitMeasure(): ActiveQuery
    {
        return $this->hasOne(UnitMeasure::class, ['id' => 'unit_measure_id']);
    }

    /**
     * Gets query for [[WorkListsMaterials]].
     */
    public function getWorkType(): ActiveQuery
    {
        return $this->hasOne(WorkType::class, ['id' => 'work_type_id']);
    }
}
