<?php

namespace common\entities\Dictionaries;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "{{%work_lists_materials}}".
 *
 * @property int $id
 * @property int $work_list_id Запись работы
 * @property string $name Наименование материала
 * @property int $unit_measure_id Запись единицы измерения
 * @property int $sort Сортировка
 * @property int $created_at Дата создания
 * @property int $updated_at Дата обновления
 *
 * @property ConsumptionRatesMaterial[] $consumptionRatesMaterials
 * @property ConsumptionRate[] $consumptionRates
 * @property WorkList $workList
 * @property UnitMeasure $unitMeasure
 */
class WorkListsMaterial extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%work_lists_materials}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['work_list_id', 'name', 'unit_measure_id'], 'required'],
            [['work_list_id', 'unit_measure_id', 'created_at', 'updated_at', 'sort'], 'integer'],
            [['name'], 'string', 'max' => 255],
            [['work_list_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkList::class, 'targetAttribute' => ['work_list_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'work_list_id' => 'Запись нормы расхода',
            'name' => 'Материал',
            'unit_measure_id' => 'Единица измерения',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            TimestampBehavior::class,
        ];
    }

    /**
     * Создание/Редактирование записи.
     */
    public function create($name, $unit_measure_id, $work_list_id, $sort): void
    {
        $this->name = $name;
        $this->unit_measure_id = $unit_measure_id;
        $this->work_list_id = $work_list_id;
        $this->sort = $sort;
    }

    /**
     * Gets query for [[ConsumptionRatesMaterials]].
     */
    public function getConsumptionRatesMaterials(): ActiveQuery
    {
        return $this->hasMany(ConsumptionRatesMaterial::class, ['material_id' => 'id']);
    }

    /**
     * Gets query for [[ConsumptionRatesMaterials]].
     */
    public function getConsumptionRates(): ActiveQuery
    {
        return $this->hasMany(ConsumptionRate::class, ['work_list_id' => 'work_list_id']);
    }

    /**
     * Gets query for [[WorkList]].
     */
    public function getWorkList(): ActiveQuery
    {
        return $this->hasOne(WorkList::class, ['id' => 'work_list_id']);
    }

    /**
     * Gets query for [[WorkList]].
     */
    public function getUnitMeasure(): ActiveQuery
    {
        return $this->hasOne(UnitMeasure::class, ['id' => 'unit_measure_id']);
    }

    /**
     * Получение массива записей материалов к работе
     */
    public static function workMaterialsList(): array
    {
        return ArrayHelper::map(self::find()->all(), 'id', 'name');
    }
}
