<?php

namespace common\entities\Dictionaries;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;

/**
 * This is the model class for table "work_types".
 *
 * @property int $id
 * @property string $name Наименование
 * @property string $alias Сокращение
 * @property string|null $description Описание
 * @property int $created_at Дата создания
 * @property int $updated_at Дата обновления
 */
class WorkType extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%work_types}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['name', 'alias', 'description'], 'required'],
            [['created_at', 'updated_at'], 'integer'],
            [['name'], 'string', 'max' => 128],
            [['alias'], 'string', 'max' => 6],
            [['description'], 'string', 'max' => 512],
            [['name'], 'unique'],
            [['alias'], 'unique'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'name' => 'Наименование',
            'alias' => 'Сокращение',
            'description' => 'Описание',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function behaviors(): array
    {
        return [
            TimestampBehavior::class,
        ];
    }

    /**
     * Массив типов работ по ID и сокращению.
     */
    public static function workTypesList(): array
    {
        return ArrayHelper::map(self::find()->all(), 'id', 'alias');
    }
}
