<?php

namespace common\entities\Project;

use common\entities\Dictionaries\ConsumptionRate;
use common\entities\Dictionaries\WorkList;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "{{%figures}}".
 *
 * @property int $id
 * @property int $image_id Запись изображения
 * @property int $type Тип фигуры
 * @property string $coordinates Координаты
 * @property string|null $title Наименование области
 * @property float|null $length Длина
 * @property float|null $width Ширина
 * @property float|null $area Площадь
 * @property float|null $footage Объем
 * @property int $work_list_id Запись работы
 * @property int $consumption_rate_id Запись нормы расхода
 * @property int $stage Этаж
 *
 * @property ProjectImage $image
 * @property WorkList $work
 * @property ConsumptionRate $consumptionRate
 */
class Figure extends ActiveRecord
{
    public const TYPE_RECT = 10;
    public const TYPE_TRIANGLE = 20;
    public const TYPE_CIRCLE = 30;
    public const TYPE_LINE = 40;

    /**
     * Создание записи.
     */
    public static function create(
        int $image_id,
        ?int $type,
        ?string $coordinates,
        ?string $title,
        ?float $length,
        ?float $width,
        ?float $area,
        ?float $footage,
        ?int $work_list_id,
        ?int $consumption_rate_id
    ): self {
        $figure = new static();
        $figure->image_id = $image_id;
        $figure->type = $type;
        $figure->coordinates = $coordinates;
        $figure->title = $title;
        $figure->length = $length;
        $figure->width = $width;
        $figure->area = $area;
        $figure->footage = $footage;
        $figure->work_list_id = $work_list_id;
        $figure->consumption_rate_id = $consumption_rate_id;

        return $figure;
    }

    public static function tableName(): string
    {
        return '{{%figures}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['image_id'], 'required'],
            [['image_id', 'type', 'work_list_id', 'consumption_rate_id'], 'integer'],
            [['coordinates'], 'string'],
            [['length', 'width', 'area', 'footage'], 'number'],
            [['title'], 'string', 'max' => 255],
            [['image_id'], 'exist', 'skipOnError' => true, 'targetClass' => ProjectImage::class, 'targetAttribute' => ['image_id' => 'id']],
            [['work_list_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkList::class, 'targetAttribute' => ['work_list_id' => 'id']],
            [[
                'consumption_rate_id',
            ], 'exist', 'skipOnError' => true, 'targetClass' => ConsumptionRate::class, 'targetAttribute' => ['consumption_rate_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'image_id' => 'Запись изображения',
            'type' => 'Тип фигуры',
            'coordinates' => 'Координаты',
            'title' => 'Наименование области',
            'length' => 'Длина',
            'width' => 'Ширина',
            'area' => 'Площадь',
            'footage' => 'Объем',
            'work_list_id' => 'Запись работы',
            'consumption_rate_id' => 'Запись нормы расхода',
        ];
    }

    /**
     * Редактирование записи.
     */
    public function edit(
        int $image_id,
        ?int $type,
        ?string $coordinates,
        ?string $title,
        ?float $length,
        ?float $width,
        ?float $area,
        ?float $footage,
        ?int $work_list_id,
        ?int $consumption_rate_id
    ): void {
        $this->image_id = $image_id;
        $this->type = $type;
        $this->coordinates = $coordinates;
        $this->title = $title;
        $this->length = $length;
        $this->width = $width;
        $this->area = $area;
        $this->footage = $footage;
        $this->work_list_id = $work_list_id;
        $this->consumption_rate_id = $consumption_rate_id;
    }

    /**
     * Возвращает массив типов фигуры.
     */
    public static function typeList(): array
    {
        return [
            self::TYPE_RECT => 'Прямоугольник',
            self::TYPE_TRIANGLE => 'Треугольник',
            self::TYPE_CIRCLE => 'Круг',
            self::TYPE_LINE => 'Линия',
        ];
    }

    /**
     * Gets query for [[Image]].
     */
    public function getImage(): ActiveQuery
    {
        return $this->hasOne(ProjectImage::class, ['id' => 'image_id']);
    }

    /**
     * Gets query for [[Work]].
     */
    public function getWork(): ActiveQuery
    {
        return $this->hasOne(WorkList::class, ['id' => 'work_list_id']);
    }

    /**
     * Gets query for [[ConsumptionRate]].
     */
    public function getConsumptionRate(): ActiveQuery
    {
        return $this->hasOne(ConsumptionRate::class, ['id' => 'consumption_rate_id']);
    }
}
