<?php

namespace common\entities\Project;

use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use common\entities\Dictionaries\WorkType;
use yii\db\ActiveQuery;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "{{%project_works_contractors}}".
 *
 * @property int $id
 * @property int $contract_id Запись договора
 * @property int $work_type_id Запись типа работы
 * @property int $contractor_id Ответственный за исполнение
 *
 * @property Contract $contract
 * @property WorkType $workType
 * @property ContractCompany $contractor
 */
class ProjectWorksContractor extends ActiveRecord
{
    public static function tableName(): string
    {
        return '{{%project_works_contractors}}';
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['contract_id', 'work_type_id'], 'required'],
            [['contract_id', 'work_type_id', 'contractor_id'], 'integer'],
            [['contract_id'], 'exist', 'skipOnError' => true, 'targetClass' => Contract::class, 'targetAttribute' => ['contract_id' => 'id']],
            [['work_type_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkType::class, 'targetAttribute' => ['work_type_id' => 'id']],
            [
                [
                    'contractor_id',
                ],
                'exist', 'skipOnError' => true, 'targetClass' => ContractCompany::class, 'targetAttribute' => ['contractor_id' => 'company_id'],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'contract_id' => 'Запись договора',
            'work_type_id' => 'Запись типа работы',
            'contractor_id' => 'Ответственный за исполнение',
        ];
    }

    /**
     * Создание/Редактирование записей.
     */
    public static function edit($projectPages): bool
    {
        foreach ($projectPages as $projectPage) {
            if (!($model = self::findOne(['contract_id' => $projectPage['contract_id'], 'work_type_id' => $projectPage['work_type_id']]))) {
                $model = new static();
            }
            $model->contract_id = $projectPage['contract_id'];
            $model->work_type_id = $projectPage['work_type_id'];

            $model->save();
        }

        return true;
    }

    /**
     * Gets query for [[Contract]].
     */
    public function getContract(): ActiveQuery
    {
        return $this->hasOne(Contract::class, ['id' => 'contract_id']);
    }

    /**
     * Gets query for [[WorkType]].
     */
    public function getWorkType(): ActiveQuery
    {
        return $this->hasOne(WorkType::class, ['id' => 'work_type_id']);
    }

    /**
     * Gets query for [[ContractCompany]].
     */
    public function getContractor(): ActiveQuery
    {
        return $this->hasOne(ContractCompany::class, ['company_id' => 'contractor_id']);
    }

    public function getImages(): ActiveQuery
    {
        return $this->hasMany(ProjectImage::class, ['contract_id' => 'contract_id', 'work_type_id' => 'work_type_id']);
    }
}
