<?php

namespace common\forms\Company;

use common\entities\behaviors\JsonValidator;
use common\entities\Company\Company;
use yii\base\Model;

class CompanyForm extends Model
{
    /** @var string|int|null $id */
    public ?int $id = null;

    public ?string $full_name = null;
    public ?string $short_name = null;
    public ?string $delegate_name = null;
    public ?string $delegate_email = null;
    public ?string $signer_post = null;
    public ?string $signer_name = null;
    public ?string $general_email = null;
    public ?string $legal_adress = null;
    public ?string $physical_adress = null;
    public ?string $inn = null;
    public ?string $ogrn = null;
    public ?string $okpo = null;
    public ?string $kpp = null;
    public ?string $company_url = null;
    public ?string $payment_account = null;
    public ?string $bank = null;
    public ?string $bank_cor_account = null;
    public ?string $bank_bic = null;

    /** @var string|int|null $company_type */
    public $company_type = null;

    /** @var string|array<string>|null $delegate_phones */
    public $delegate_phones = null;

    /** @var string|array<string>|null $general_phones */
    public $general_phones = null;

    /** @var string|int|null $is_client */
    public $is_client = false;

    /** @var string|int|null $created_at */
    public $created_at = null;

    /** @var string|int|null $updated_at */
    public $updated_at = null;

    private ?Company $company = null;

    /** @param array<string> $config */
    public function __construct(?Company $company = null, array $config = [])
    {
        if ($company) {
            $this->id = $company->id;
            $this->full_name = $company->full_name;
            $this->short_name = $company->short_name;
            $this->delegate_name = $company->delegate_name;
            $this->delegate_phones = $company->delegate_phones;
            $this->delegate_email = $company->delegate_email;
            $this->signer_post = $company->signer_post;
            $this->signer_name = $company->signer_name;
            $this->general_phones = $company->general_phones;
            $this->general_email = $company->general_email;
            $this->legal_adress = $company->legal_adress;
            $this->physical_adress = $company->physical_adress;
            $this->company_type = $company->company_type;
            $this->inn = $company->inn;
            $this->ogrn = $company->ogrn;
            $this->okpo = $company->okpo;
            $this->kpp = $company->kpp;
            $this->company_url = $company->company_url;
            $this->payment_account = $company->payment_account;
            $this->bank = $company->bank;
            $this->bank_cor_account = $company->bank_cor_account;
            $this->bank_bic = $company->bank_bic;
            $this->is_client = $company->is_client;
            $this->created_at = $company->created_at;
            $this->updated_at = $company->updated_at;

            $this->company = $company;
        }

        parent::__construct($config);
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['full_name', 'short_name', 'delegate_name', 'delegate_phones', 'delegate_email', 'signer_post', 'signer_name', 'legal_adress'], 'required'],
            [['physical_adress', 'company_type', 'inn', 'ogrn', 'okpo', 'kpp', 'payment_account', 'bank', 'bank_cor_account', 'bank_bic'], 'required'],
            [
                ['inn',],
                'unique',
                'targetClass' => Company::class,
                'targetAttribute' => 'inn',
                'filter' => $this->company ? ['<>', 'id', $this->company->id] : null,
            ],
            [
                ['ogrn',],
                'unique',
                'targetClass' => Company::class,
                'targetAttribute' => 'ogrn',
                'filter' => $this->company ? ['<>', 'id', $this->company->id] : null,
            ],
            [
                ['okpo',],
                'unique',
                'targetClass' => Company::class,
                'targetAttribute' => 'okpo',
                'filter' => $this->company ? ['<>', 'id', $this->company->id] : null,
            ],
            [
                ['kpp',],
                'unique',
                'targetClass' => Company::class,
                'targetAttribute' => 'kpp',
                'filter' => $this->company ? ['<>', 'id', $this->company->id] : null,
            ],
            [
                ['payment_account',],
                'unique',
                'targetClass' => Company::class,
                'targetAttribute' => 'payment_account',
                'filter' => $this->company ? ['<>', 'id', $this->company->id] : null,
            ],
            [['delegate_phones', 'general_phones'], JsonValidator::class],
            [['delegate_email', 'general_email'], 'email'],
            [['company_url'], 'url'],
            ['delegate_phones',
                'each',
                'rule' => ['match', 'pattern' => '/^\+7\s\([0-9]{3}\)\s[0-9]{3}\-[0-9]{2}\-[0-9]{2}$/', 'message' => 'Неверный номер телефона']],
            ['general_phones',
                'each',
                'rule' => ['match', 'pattern' => '/^\+7\s\([0-9]{3}\)\s[0-9]{3}\-[0-9]{2}\-[0-9]{2}$/', 'message' => 'Неверный номер телефона']],
            [['company_type', 'created_at', 'updated_at'], 'integer'],
            [['is_client'], 'boolean'],
            [['full_name', 'short_name', 'delegate_name', 'delegate_email', 'signer_post', 'signer_name', 'general_email'], 'string', 'max' => 255],
            [['legal_adress', 'physical_adress', 'bank'], 'string', 'max' => 255],
            [['inn'], 'string', 'min' => 10, 'max' => 10],
            [['okpo'], 'string', 'min' => 8, 'max' => 10],
            [['ogrn'], 'string', 'min' => 13, 'max' => 13],
            [['kpp', 'bank_bic'], 'string', 'min' => 9, 'max' => 9],
            [['payment_account', 'bank_cor_account'], 'string', 'min' => 20, 'max' => 20],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'full_name' => 'Полное наименование',
            'short_name' => 'Короткое наименование',
            'delegate_name' => 'ФИО представителя',
            'delegate_phones' => 'Контактный телефон представителя',
            'delegate_email' => 'Почта представителя',
            'signer_post' => 'Должность подписанта',
            'signer_name' => 'ФИО подписанта',
            'general_phones' => 'Общий телефон компании',
            'general_email' => 'Общая почта',
            'legal_adress' => 'Юридический адрес',
            'physical_adress' => 'Фактический адрес',
            'company_type' => 'Тип организации',
            'inn' => 'ИНН',
            'ogrn' => 'ОГРН',
            'okpo' => 'ОКПО',
            'kpp' => 'КПП',
            'company_url' => 'Ссылка на сайт',
            'payment_account' => 'Р/С',
            'bank' => 'Банк',
            'bank_cor_account' => 'К/С',
            'bank_bic' => 'БИК',
            'is_client' => 'Является клиентом',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }
}
