<?php

namespace common\forms\Contract;

use common\entities\Contract\Contract;
use yii\base\Model;

class ContractAmountForm extends Model
{
    /** @var string|int|null $is_prepayment */
    public $is_prepayment = null;

    /** @var string|int|null $prepayment_percent */
    public $prepayment_percent = null;

    /** @var string|int|null $report_start_day */
    public $report_start_day = null;

    /** @var string|int|null $report_end_day */
    public $report_end_day = null;

    public ?string $date_works_start = null;

    public ?string $date_works_end = null;

    /** @var string|float|null $amount */
    public $amount = null;

    /** @var string|int|null $is_nds */
    public $is_nds = null;

    /** @param array<string> $config */
    public function __construct(Contract $contract, array $config = [])
    {
        $this->is_prepayment = $contract->is_prepayment;
        $this->prepayment_percent = $contract->prepayment_percent;
        $this->report_start_day = $contract->report_start_day;
        $this->report_end_day = $contract->report_end_day;
        $this->date_works_start = $contract->date_works_start;
        $this->date_works_end = $contract->date_works_end;
        $this->amount = $contract->amount;
        $this->is_nds = $contract->is_nds;

        parent::__construct($config);
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['is_prepayment', 'report_start_day', 'report_end_day', 'date_works_start', 'date_works_end', 'amount'], 'required'],
            [['is_prepayment', 'is_nds', 'report_start_day', 'report_end_day'], 'integer'],
            [['prepayment_percent'], 'integer', 'min' => 10, 'max' => 30],
            [['date_works_start', 'date_works_end'], 'string'],
            ['date_works_end', 'validateDateWorksEnd'],
            [['amount'], 'number', 'min' => 0],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'is_prepayment' => 'Авансовый платеж',
            'prepayment_percent' => 'Процент авансового платежа',
            'report_start_day' => 'Число начала отчетного периода',
            'report_end_day' => 'Число окончания отчетного периода',
            'date_works_start' => 'Дата начала работ',
            'date_works_end' => 'Дата окончания работ',
            'amount' => 'Общая стоимость',
            'is_nds' => 'НДС',
        ];
    }

    public function validateDateWorksEnd($attribute)
    {
        if ($this->date_works_end < $this->date_works_start) {
            $this->addError($attribute, 'Дата окончания работ не может быть меньше даты начала работ');
        }
    }
}
