<?php

namespace common\forms\Contract;

use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use common\entities\Contract\ContractEstimate;
use common\entities\Dictionaries\WorkList;
use common\entities\Dictionaries\WorkType;
use Exception;
use yii\base\Model;
use yii\helpers\ArrayHelper;

class ContractEstimateForm extends Model
{
    /** @var string|int|null $id */
    public $id = null;

    /** @var string|int|null $contract_id */
    public $contract_id = null;

    /** @var string|int|null $work_type_id */
    public $work_type_id = null;

    /** @var string|int|null $surface */
    public $surface = null;

    public ?string $bill_number = null;

    public ?string $bill_date = null;

    /** @var string|int|null $updated_at */
    public $work_list_id = null;

    /** @var string|int|null $type */
    public $type = null;

    /** @var string|int|null $contractor_id */
    public $contractor_id = null;

    /** @var string|float|null $quantity */
    public $quantity = null;

    /** @var string|float|null $price_per_unit */
    public $price_per_unit = null;

    /** @var string|int|null $markup */
    public $markup = null;

    /** @var string|int|null $created_at */
    public $created_at = null;

    /** @var string|int|null $updated_at */
    public $updated_at = null;

    /** @param array<string> $config */
    public function __construct(?ContractEstimate $estimate = null, array $config = [])
    {
        if ($estimate) {
            $this->id = $estimate->id;
            $this->contract_id = $estimate->contract_id;
            $this->work_type_id = $estimate->work_type_id;
            $this->surface = $estimate->surface;
            $this->bill_number = $estimate->bill_number;
            $this->bill_date = $estimate->bill_date;
            $this->work_list_id = $estimate->work_list_id;
            $this->type = $estimate->type;
            $this->contractor_id = $estimate->contractor_id;
            $this->quantity = $estimate->quantity;
            $this->price_per_unit = $estimate->price_per_unit;
            $this->markup = $estimate->markup;
            $this->created_at = $estimate->created_at;
            $this->updated_at = $estimate->updated_at;
        }

        parent::__construct($config);
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['contract_id', 'work_type_id', 'surface', 'bill_number'], 'required'],
            [['work_list_id', 'type', 'contractor_id', 'quantity', 'price_per_unit'], 'required'],
            [['contract_id', 'work_type_id', 'surface', 'work_list_id', 'type', 'contractor_id', 'created_at', 'updated_at'], 'integer'],
            [['markup'], 'integer', 'min' => 0, 'max' => 100],
            [['bill_date'], 'string'],
            [['quantity', 'price_per_unit'], 'number', 'min' => 0],
            [['bill_number'], 'string', 'max' => 255],
            [['contract_id'], 'exist', 'skipOnError' => true, 'targetClass' => Contract::class, 'targetAttribute' => ['contract_id' => 'id']],
            [['work_type_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkType::class, 'targetAttribute' => ['work_type_id' => 'id']],
            [['work_list_id'], 'exist', 'skipOnError' => true, 'targetClass' => WorkList::class, 'targetAttribute' => ['work_list_id' => 'id']],
            [
                [
                    'contractor_id',
                ],
                'exist', 'skipOnError' => true, 'targetClass' => ContractCompany::class, 'targetAttribute' => ['contractor_id' => 'company_id'],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'contract_id' => 'Договор',
            'work_type_id' => 'Тип работы из справочника',
            'surface' => 'Поверхность',
            'bill_number' => 'Номер счета/накладной',
            'bill_date' => 'Дата счета/накладной',
            'work_list_id' => 'Работа',
            'type' => 'Тип работы',
            'contractor_id' => 'Ответственный за исполнение',
            'quantity' => 'Количество',
            'price_per_unit' => 'Цена за единицу',
            'markup' => 'Наценка',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * Получение значения типа работы
     *
     * @throws Exception
     */
    public static function typeName(int $type): string
    {
        return ArrayHelper::getValue(ContractEstimate::typeList(), $type);
    }

    /**
     * Получение значения поверхности
     *
     * @throws Exception
     */
    public static function surfaceName(int $surface): string
    {
        return ArrayHelper::getValue(ContractEstimate::surfaceList(), $surface);
    }
}
