<?php

namespace common\forms\Contract;

use common\entities\Company\Company;
use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use Exception;
use yii\base\Model;
use yii\helpers\ArrayHelper;

class ContractForm extends Model
{
    /** @var string|int|null $id */
    public $id = null;

    /** @var string|int|null $company_id */
    public $company_id = null;

    public ?string $number = null;

    public ?string $date_start = null;

    public ?string $subject_address = null;

    public ?string $subject_name = null;

    /** @var string|int|null $is_act_counter_increase_annually */
    public $is_act_counter_increase_annually = null;

    /** @var string|int|null $documents_day_end */
    public $documents_day_end = null;

    /** @var string|int|null $status */
    public $status = null;

    /** @var string|int|null $created_at */
    public $created_at = null;

    /** @var string|int|null $updated_at */
    public $updated_at = null;

    private ?Contract $contract = null;

    /** @param array<string> $config */
    public function __construct(?Contract $contract = null, array $config = [])
    {
        if ($contract) {
            $this->id = $contract->id;
            $this->company_id = $contract->company_id;
            $this->number = $contract->number;
            $this->date_start = $contract->date_start;
            $this->subject_address = $contract->subject_address;
            $this->subject_name = $contract->subject_name;
            $this->is_act_counter_increase_annually = $contract->is_act_counter_increase_annually;
            $this->documents_day_end = $contract->documents_day_end;
            $this->status = $contract->status;
            $this->created_at = $contract->created_at;
            $this->updated_at = $contract->updated_at;

            $this->contract = $contract;
        }

        parent::__construct($config);
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['company_id', 'number', 'date_start', 'documents_day_end'], 'required'],
            [['company_id', 'is_act_counter_increase_annually', 'status', 'created_at', 'updated_at'], 'integer'],
            [['documents_day_end'], 'integer'],
            [['date_start'], 'string'],
            [['number', 'subject_name'], 'string', 'max' => 255],
            [['subject_address'], 'string', 'max' => 512],
            [
                ['number',],
                'unique',
                'targetClass' => Contract::class,
                'targetAttribute' => 'number',
                'filter' => $this->contract ? ['<>', 'id', $this->contract->id] : null,
            ],
            [['company_id'], 'exist', 'skipOnError' => true, 'targetClass' => Company::class, 'targetAttribute' => ['company_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels(): array
    {
        return [
            'id' => 'ID',
            'company_id' => 'Юридическое лицо',
            'number' => 'Номер договора',
            'date_start' => 'Дата создания',
            'subject_address' => 'Адрес объекта',
            'subject_name' => 'Наименование объекта',
            'is_act_counter_increase_annually' => 'Обновление счетчика акта после нг',
            'documents_day_end' => 'Число закрытия документов',
            'status' => 'Статус',
            'created_at' => 'Дата создания',
            'updated_at' => 'Дата обновления',
        ];
    }

    /**
     * Получение значения статуса пользователя
     *
     * @throws Exception
     */
    public static function statusName(int $status): string
    {
        return ArrayHelper::getValue(Contract::statusList(), $status);
    }

    /**
     * Получение значения статуса юрлица
     *
     * @throws Exception
     */
    public static function roleName(int $role): string
    {
        return ArrayHelper::getValue(ContractCompany::roleList(), $role);
    }
}
