<?php

namespace common\helpers;

use common\entities\Contract\ContractEstimate;
use yii\data\ActiveDataProvider;

class ContractEstimateHelper
{
    /**
     * Таблица по суммам в смете.
     */
    public static function amounts(ActiveDataProvider $dataProvider): array
    {
        $amount = 0;
        $amountNds = 0;
        $amountMaterials = self::amountPerType($dataProvider, ContractEstimate::TYPE_MATERIALS);
        $amountExpMaterials = self::amountPerType($dataProvider, ContractEstimate::TYPE_EXP_MATERIALS);
        $amountEquipment = self::amountPerType($dataProvider, ContractEstimate::TYPE_EQUIPMENT);
        $amountTransport = self::amountPerType($dataProvider, ContractEstimate::TYPE_TRANSPORT);
        $amountSalary = self::amountPerType($dataProvider, ContractEstimate::TYPE_SALARY);
        $salary = 0;

        foreach ($dataProvider->getModels() as $model) {
            $amount += $model->estimateAmount();
            $amountNds += $model->estimateAmountWithNds();
            if ($model->type === ContractEstimate::TYPE_SALARY) {
                $salary += $model->quantity;
            }
        }

        return [
            'amount' => DecimalNumberHelper::numFormat($amount),
            'amountNds' => DecimalNumberHelper::numFormat($amountNds),
            'amountMaterials' => DecimalNumberHelper::numFormat($amountMaterials),
            'amountExpMaterials' => DecimalNumberHelper::numFormat($amountExpMaterials),
            'amountEquipment' => DecimalNumberHelper::numFormat($amountEquipment),
            'amountTransport' => DecimalNumberHelper::numFormat($amountTransport),
            'amountSalary' => DecimalNumberHelper::numFormat($amountSalary),
            'salary' => DecimalNumberHelper::numFormat($salary),
        ];
    }

    public static function amountPerType(ActiveDataProvider $dataProvider, int $type): int
    {
        $amount = 0;
        foreach ($dataProvider->getModels() as $model) {
            if ($model->type === $type) {
                $amount += $model->estimateAmount();
            }
        }

        return $amount;
    }
}
