<?php

namespace common\helpers;

use common\entities\User\User;
use Exception;
use yii\helpers\ArrayHelper;
use yii\helpers\Html;

class UserHelper
{
    public static function statusList(): array
    {
        return [
            User::STATUS_INACTIVE => 'Неактивный',
            User::STATUS_ACTIVE => 'Активный',
            User::STATUS_DELETED => 'Удален',
        ];
    }

    /**
     * Получение значения статуса пользователя
     *
     * @throws Exception
     */
    public static function statusName(int $status): string
    {
        return ArrayHelper::getValue(self::statusList(), $status);
    }

    /**
     * Формирования тега для статуса пользователя
     *
     * @throws Exception
     */
    public static function statusLabel(int $status): string
    {
        switch ($status) {
            case User::STATUS_INACTIVE:
                $class = 'label label-default';
                break;
            case User::STATUS_ACTIVE:
                $class = 'label label-success';
                break;
            case User::STATUS_DELETED:
                $class = 'label label-danger';
                break;
            default:
                $class = 'label label-default';
        }

        return Html::tag('span', ArrayHelper::getValue(self::statusList(), $status), [
            'class' => $class,
        ]);
    }
}
