<?php

namespace common\modules\entitiesHistory\entities;

use common\entities\User\User;
use common\modules\entitiesHistory\HistoryModule;
use Exception;
use Yii;
use yii\base\InvalidConfigException;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;

/**
 * Аттрибуты коллекции изменений.
 *
 * @property int $id
 * @property string $table_name Имя таблицы источника
 * @property string $model_name Модель источника
 * @property int $row_id ID сущности источника
 * @property int $event Событие триггер
 * @property int $created_at Дата создания
 * @property int $created_by Автор изменения
 * @property string|null $field_name Аттрибут
 * @property string|null $old_value Старое значение
 * @property string|null $new_value Новое значение
 */
class History extends ActiveRecord
{
    public const EVENT_INSERT = 1;
    public const EVENT_UPDATE = 2;
    public const EVENT_DELETE = 3;

    public static function tableName(): string
    {
        return HistoryModule::getInstance()->tableName;
    }

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['table_name', 'model_name', 'row_id', 'event', 'created_at', 'created_by'], 'required'],
            [['row_id', 'event', 'created_at', 'created_by'], 'integer'],
            [['old_value', 'new_value'], 'string'],
            [['table_name', 'model_name', 'field_name'], 'string', 'max' => 255],
        ];
    }

    public function attributeLabels(): array
    {
        return [
            'event' => 'Триггер',
            'field_name' => 'Атрибут',
            'old_value' => 'Старое значение',
            'new_value' => 'Новое значение',
            'created_at' => 'Дата создания записи',
            'created_by' => 'Автор изменения',
        ];
    }

    /** @throws Exception */
    public static function eventsList(): array
    {
        return [
            self::EVENT_INSERT => 'Создание записи',
            self::EVENT_UPDATE => 'Обновление записи',
            self::EVENT_DELETE => 'Удаление записи',
        ];
    }

    /** @throws Exception */
    public function getEventName(): string
    {
        return ArrayHelper::getValue(self::eventsList(), $this->event);
    }

    /**
     * Получение наименования атрибута.
     */
    public function getModelAttributeLabel(): string
    {
        $model = new $this->model_name();
        return $model->getAttributeLabel($this->field_name);
    }

    /**
     * Получение логина пользователя.
     */
    public function getCreatedByName(): string
    {
        return User::findOne(['id' => $this->created_by])->username;
    }

    /**
     * Получение модели источника.
     * @throws InvalidConfigException
     */
    public function getModel(): ActiveRecord
    {
        $model = Yii::createObject([
            'class' => $this->model_name,
        ]);
        $item = $this->findModel($model);
        if ($item) {
            return $item;
        }

        return new $model();
    }

    /**
     * @param $model
     * @return false|ActiveRecord
     */
    public function findModel($model)
    {
        if ($item = $model::findOne($this->row_id)) {
            return $item;
        }

        return false;
    }
}
