<?php

namespace common\modules\entitiesHistory\entities;

use yii\data\ActiveDataProvider;
use yii\db\ActiveQuery;

/**
 * Модель для поиска записей истории.
 */
class HistoryQuery extends History
{
    /**
     * Конструктор запросов
     */
    protected ?ActiveQuery $mainQuery;

    /**
     * {@inheritdoc}
     */
    public function rules(): array
    {
        return [
            [['row_id', 'event', 'created_at', 'created_by'], 'integer'],
            [['table_name', 'model_name', 'field_name', 'old_value', 'new_value'], 'string'],
        ];
    }

    /**
     * Поиск записей по условиям.
     *
     * @param $params
     * @param $modelClass
     */
    public function search($params, $modelClass): ActiveDataProvider
    {
        $this->mainQuery = self::find()->where(['model_name' => $modelClass]);
        $dataProvider = new ActiveDataProvider([
            'query' => $this->mainQuery,
            'sort' => [
                'defaultOrder' => [
                    'created_at' => SORT_DESC,
                ],
            ],
        ]);

        if (!$this->load($params)) {
            return $dataProvider;
        }

        $this->filterAttributes();

        return $dataProvider;
    }

    /**
     * Построение запроса на выборку
     */
    public function buildQuery(): ?ActiveQuery
    {
        $this->mainQuery = self::find();
        $this->filterAttributes();

        return $this->mainQuery;
    }

    /**
     * Фильтрация по атрибутам
     */
    protected function filterAttributes(): void
    {
        if ($this->mainQuery) {
            if ($this->hasAttribute('row_id')) {
                $this->mainQuery->andFilterWhere(['row_id' => $this->row_id]);
            }
            if ($this->hasAttribute('event')) {
                $this->mainQuery->andFilterWhere(['event' => $this->event]);
            }
            if ($this->hasAttribute('field_name')) {
                $this->mainQuery->andFilterWhere(['field_name' => $this->field_name]);
            }
            if ($this->hasAttribute('old_value')) {
                $this->mainQuery->andFilterWhere(['old_value' => $this->old_value]);
            }
            if ($this->hasAttribute('new_value')) {
                $this->mainQuery->andFilterWhere(['new_value' => $this->new_value]);
            }
            if ($this->hasAttribute('created_at')) {
                $this->mainQuery->andFilterWhere(['created_at' => $this->created_at]);
            }
            if ($this->hasAttribute('created_by')) {
                $this->mainQuery->andFilterWhere(['created_by' => $this->created_by]);
            }
        }
    }
}
