<?php

namespace common\modules\entitiesHistory\storages;

use common\modules\entitiesHistory\forms\HistoryForm;
use common\modules\entitiesHistory\HistoryModule;
use common\modules\entitiesHistory\storages\Base as BaseStorage;
use yii\db\Exception;

class Database extends BaseStorage
{
    protected ?HistoryModule $module;

    public function init()
    {
        parent::init();

        $this->module = HistoryModule::getInstance();
    }

    /** @throws Exception */
    public function flush(): bool
    {
        $collection = $this->getCollection();
        if (!empty($collection)) {
            [$sql, $params] = $this->prepareQuery($collection);
            return (bool) $this->module->db->createCommand($sql, $params)->execute();
        }

        return true;
    }
    
    /**
     * SQL query для коллекции изменений.
     * @param HistoryForm[] $collection
     */
    protected function prepareQuery(array $collection): array
    {
        $queryBuilder = $this->module->db->getQueryBuilder();
        $sql = [];
        $params = [];
        for ($i = 0; $i != count($collection); $i++) {
            $row = [
                'table_name' => $collection[$i]->tableName,
                'model_name' => $collection[$i]->modelName,
                'field_name' => $collection[$i]->fieldName,
                'row_id' => $collection[$i]->rowId,
                'old_value' => $collection[$i]->oldValue,
                'new_value' => $collection[$i]->newValue,
                'event' => $collection[$i]->event,
                'created_at' => $collection[$i]->createdAt,
                'created_by' => $collection[$i]->createdBy,
            ];
            $sql[] = $queryBuilder->insert($this->module->tableName, $row, $params);
        }

        return [implode(';' . PHP_EOL, $sql), $params];
    }
}
