<?php

namespace common\readModels;

use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use yii\data\ActiveDataProvider;
use yii\data\DataProviderInterface;
use yii\db\ActiveQuery;

class ContractReadRepository
{
    /**
     * Поиск договора по ID.
     */
    public function find(int $id): ?Contract
    {
        return Contract::findOne($id);
    }

    /**
     * Поиск договоров по ID юридического лица.
     */
    public function getContractsByCompany($companyId): DataProviderInterface
    {
        $query = Contract::find()->where(['company_id' => $companyId]);

        return $this->getProvider($query);
    }

    /**
     * Поиск действующего договора.
     */
    public static function findActiveById(int $id): ?Contract
    {
        return Contract::findOne(['id' => $id, 'status' => Contract::STATUS_ACTIVE]);
    }

    /**
     * Gets query for [[ContractCompanies]].
     */
    public static function getContractCompanies($id): array
    {
        return ContractCompany::findAll(['contract_id' => $id]);
    }

    private function getProvider(ActiveQuery $query): ActiveDataProvider
    {
        return new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSizeLimit' => [15, 100],
            ],
        ]);
    }
}
