<?php

namespace common\repositories;

use common\entities\Project\Axis;
use RuntimeException;
use Throwable;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;
use yii\db\IntegrityException;
use yii\web\ForbiddenHttpException;

class AxisRepository
{
    /**
     * Поиск по ID.
     */
    public function get($id): Axis
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск по определенному условию.
     * @param array<string> $condition
     * @return Axis|ActiveRecord
     */
    private function getBy(array $condition): Axis
    {
        if (!$axis = Axis::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('Запись не найдена');
        }

        return $axis;
    }

    /**
     * Сохранение записи.
     */
    public function save(Axis $axis): void
    {
        if (!$axis->save()) {
            throw new RuntimeException('Ошибка при сохранении');
        }
    }

    /**
     * Удаление записи.
     * @throws ForbiddenHttpException
     * @throws Throwable
     */
    public function remove(Axis $axis): void
    {
        try {
            $axis->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }
    }
}
