<?php

namespace common\repositories;

use common\entities\Company\Company;
use RuntimeException;
use Throwable;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;
use yii\db\IntegrityException;
use yii\web\ForbiddenHttpException;

class CompanyRepository
{
    /**
     * Поиск по ID
     */
    public function get($id): Company
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск по определенному условию
     * @param array<string> $condition
     * @return Company|ActiveRecord
     */
    private function getBy(array $condition): Company
    {
        if (!$company = Company::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('Запись не найдена');
        }

        return $company;
    }

    /**
     * Сохранение записи
     */
    public function save(Company $company): void
    {
        if (!$company->save()) {
            throw new RuntimeException('Ошибка при сохранении');
        }
    }

    /**
     * Удаление записи
     * @throws ForbiddenHttpException
     * @throws Throwable
     */
    public function remove(Company $company): void
    {
        try {
            $company->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }
    }
}
