<?php

namespace common\repositories;

use common\entities\Contract\ContractCompany;
use RuntimeException;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;
use yii\db\IntegrityException;
use yii\db\StaleObjectException;
use yii\web\ForbiddenHttpException;

class ContractCompanyRepository
{
    /**
     * Поиск по ID
     */
    public function get($id): ContractCompany
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск по определенному условию
     * @param array<string> $condition
     * @return ContractCompany|ActiveRecord
     */
    private function getBy(array $condition): ContractCompany
    {
        if (!$contractCompany = ContractCompany::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('Запись не найдена');
        }

        return $contractCompany;
    }

    /**
     * Сохранение записи
     */
    public function save(ContractCompany $contractCompany): void
    {
        if (!$contractCompany->save()) {
            throw new RuntimeException('Ошибка при сохранении');
        }
    }

    /**
     * Удаление записи
     * @throws ForbiddenHttpException
     * @throws \Throwable
     * @throws StaleObjectException
     */
    public function remove(ContractCompany $contractCompany): void
    {
        try {
            $contractCompany->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException(
                'Нельзя удалить данное юридическое лицо, так как оно задействовано на этапах договора'
            );
        }
    }
}
