<?php

namespace common\repositories;

use common\entities\Contract\Contract;
use RuntimeException;
use Throwable;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;
use yii\db\IntegrityException;
use yii\web\ForbiddenHttpException;

class ContractRepository
{
    /**
     * Поиск по ID
     */
    public function get($id): Contract
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск по определенному условию
     * @param array<string> $condition
     * @return Contract|ActiveRecord
     */
    private function getBy(array $condition): Contract
    {
        if (!$contract = Contract::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('Запись не найдена');
        }

        return $contract;
    }

    /**
     * Сохранение записи
     */
    public function save(Contract $contract): void
    {
        if (!$contract->save()) {
            throw new RuntimeException('Ошибка при сохранении');
        }
    }

    /**
     * Удаление записи
     * @throws ForbiddenHttpException
     * @throws Throwable
     */
    public function remove(Contract $contract): void
    {
        try {
            $contract->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }
    }
}
