<?php

namespace common\repositories;

use common\entities\Project\Figure;
use RuntimeException;
use Throwable;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;
use yii\db\IntegrityException;
use yii\web\ForbiddenHttpException;

class FigureRepository
{
    /**
     * Поиск по ID.
     */
    public function get($id): Figure
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск по определенному условию.
     * @param array<string> $condition
     * @return Figure|ActiveRecord
     */
    private function getBy(array $condition): Figure
    {
        if (!$figure = Figure::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('Запись не найдена');
        }

        return $figure;
    }

    /**
     * Сохранение записи.
     */
    public function save(Figure $figure): void
    {
        if (!$figure->save()) {
            throw new RuntimeException('Ошибка при сохранении');
        }
    }

    /**
     * Удаление записи.
     * @throws ForbiddenHttpException
     * @throws Throwable
     */
    public function remove(Figure $figure): void
    {
        try {
            $figure->delete();
        } catch (IntegrityException $e) {
            throw new ForbiddenHttpException('Данную запись нельзя удалять');
        }
    }
}
