<?php

namespace common\repositories;

use common\entities\User\User;
use RuntimeException;
use yii\base\ViewNotFoundException;
use yii\db\ActiveRecord;

class UserRepository
{
    /**
     * Поиск пользователя по логину или email
     */
    public function findByUsernameOrEmail(string $value): ?ActiveRecord
    {
        return User::find()->andWhere(['or', ['username' => $value], ['email' => $value]])->one();
    }

    /**
     * Поиск пользователя по ID
     */
    public function get(int $id): User
    {
        return $this->getBy(['id' => $id]);
    }

    /**
     * Поиск пользователя по email токену
     */
    public function getByEmailConfirmToken(string $token): User
    {
        return $this->getBy(['email_confirm_token' => $token]);
    }

    /**
     * Поиск пользователя по email
     */
    public function getByEmail(string $email): User
    {
        return $this->getBy(['email' => $email]);
    }

    /**
     * Поиск пользователя по токену сброса пароля
     */
    public function getByPasswordResetToken(string $token): User
    {
        return $this->getBy(['password_reset_token' => $token]);
    }

    /**
     * Проверка наличия пользователя по токену сброса пароля
     */
    public function existsByPasswordResetToken(string $token): bool
    {
        return (bool) User::findByPasswordResetToken($token);
    }

    /**
     * Поиск пользователя по определенному условию
     * @param array<string> $condition
     * @return User|ActiveRecord
     */
    private function getBy(array $condition): User
    {
        if (!$user = User::find()->andWhere($condition)->limit(1)->one()) {
            throw new ViewNotFoundException('User not found.');
        }

        return $user;
    }

    /**
     * Сохранение записи
     */
    public function save(User $user): void
    {
        if (!$user->save()) {
            throw new RuntimeException('Ошибка при сохранении.');
        }
    }

    /**
     * Удаление записи
     */
    public function remove(User $user): void
    {
        if (!$user->delete()) {
            throw new RuntimeException('Ошибка при удалении.');
        }
    }
}
