<?php

namespace common\services;

use common\entities\Company\Company;
use common\forms\Company\ClientForm;
use common\forms\Company\CompanyForm;
use common\repositories\CompanyRepository;

class CompanyService
{
    private CompanyRepository $company;

    public function __construct(CompanyRepository $company)
    {
        $this->company = $company;
    }

    /**
     * Создание записи.
     */
    public function create(CompanyForm $form): Company
    {
        $company = new Company();
        $company->create($form);
        $this->company->save($company);

        return $company;
    }

    /**
     * Редактирование записи.
     */
    public function edit(int $id, CompanyForm $form): Company
    {
        $company = $this->company->get($id);
        $company->create($form);
        $this->company->save($company);

        return $company;
    }

    /**
     * Удаление записи.
     */
    public function remove($id): void
    {
        $company = $this->company->get($id);
        $this->company->remove($company);
    }

    /**
     * Присвоение статуса клиента
     */
    public function makeClient(ClientForm $form): Company
    {
        $company = $this->company->get($form->client);
        $company->is_client = true;
        $this->company->save($company);

        return $company;
    }

    /**
     * Удаление статуса клиента
     */
    public function makeNoClient(ClientForm $form): Company
    {
        $company = $this->company->get($form->client);
        $company->is_client = false;
        $this->company->save($company);

        return $company;
    }
}
