<?php

namespace common\services;

use common\entities\Dictionaries\ConsumptionRatesMaterial;
use common\entities\Dictionaries\WorkListsMaterial;
use common\repositories\ConsumptionRatesMaterialRepository;

class ConsumptionRatesMaterialService
{
    private ConsumptionRatesMaterialRepository $consumptionsRateMaterial;

    public function __construct(ConsumptionRatesMaterialRepository $material)
    {
        $this->consumptionsRateMaterial = $material;
    }

    /**
     * Создание записи.
     */
    public function create(
        int $consumption_rate_id,
        int $material_id,
        ?float $material_expense = null,
        ?float $material_unit_cost = null,
        ?int $sort = 1
    ): ConsumptionRatesMaterial {
        $material = new ConsumptionRatesMaterial();
        $material->create($consumption_rate_id, $material_id, $material_expense, $material_unit_cost, $sort);
        $this->consumptionsRateMaterial->save($material);

        return $material;
    }

    /**
     * Редактирование записи.
     */
    public function edit(
        int $id,
        int $consumption_rate_id,
        int $material_id,
        ?float $material_expense = null,
        ?float $material_unit_cost = null,
        ?int $sort = 1
    ): ConsumptionRatesMaterial {
        $material = $this->consumptionsRateMaterial->get($id);
        $material->create($consumption_rate_id, $material_id, $material_expense, $material_unit_cost, $sort);
        $this->consumptionsRateMaterial->save($material);

        return $material;
    }

    /**
     * Удаление записи.
     */
    public function remove($id): void
    {
        $material = $this->consumptionsRateMaterial->get($id);
        $this->consumptionsRateMaterial->remove($material);
    }

    /**
     * Добавление материалов из работы.
     */
    public function addMaterials(int $rateId, int $workListId)
    {
        $materials = WorkListsMaterial::find()->where(['work_list_id' => $workListId])->all();
        foreach ($materials as $material) {
            $this->create($rateId, $material->id);
        }
    }

    /**
     * Пакетное обновление записей материлов к норме расходов.
     * @param array<array<string|int>> $materials
     */
    public function batchUpdate(array $materials): bool
    {
        $sort = 1;
        foreach ($materials as $material) {
            $this->edit(
                $material['id'],
                $material['consumption_rate_id'],
                $material['material_id'],
                $material['material_expense'],
                $material['material_unit_cost'],
                $sort
            );
            $sort++;
        }

        return true;
    }
}
