<?php

namespace common\services;

use common\entities\Contract\Contract;
use common\entities\Contract\ContractCompany;
use common\repositories\ContractCompanyRepository;

class ContractCompanyService
{
    private ContractCompanyRepository $contractCompany;

    public function __construct(ContractCompanyRepository $contractCompany)
    {
        $this->contractCompany = $contractCompany;
    }

    /**
     * Создание записи.
     */
    public function create($company_id, $role, $contract_id): ContractCompany
    {
        $contractCompany = new ContractCompany();
        $contractCompany->create($company_id, $role, $contract_id);
        $this->contractCompany->save($contractCompany);

        return $contractCompany;
    }

    /**
     * Редактирование записи.
     */
    public function edit(int $id, $company_id, $role, $contract_id): ContractCompany
    {
        $contractCompany = $this->contractCompany->get($id);
        $contractCompany->create($company_id, $role, $contract_id);
        $this->contractCompany->save($contractCompany);

        return $contractCompany;
    }

    /**
     * Удаление записи.
     */
    public function remove($id): void
    {
        $contractCompany = $this->contractCompany->get($id);
        $this->contractCompany->remove($contractCompany);
    }

    /**
     * Пакетное обновление записей материлов к работе.
     * @param array<array<string>> $contractCompanies
     */
    public function batchUpdate(array $contractCompanies, Contract $contract): bool
    {
        $oldIds = [];
        $newIds = [];

        foreach ($contract->contractCompanies as $oldCompanies) {
            $oldIds[] = $oldCompanies->id;
        }

        if (empty($contractCompanies) && empty($oldIds)) {
            return false;
        }

        foreach ($contractCompanies as $contractCompany) {
            if (array_key_exists('id', $contractCompany) && in_array($contractCompany['id'], $oldIds)) {
                $item = $this->edit($contractCompany['id'], $contractCompany['company_id'], $contractCompany['role'], $contract->id);
            } else {
                $item = $this->create($contractCompany['company_id'], $contractCompany['role'], $contract->id);
            }
            $newIds[] = $item->id;
        }

        foreach (array_diff($oldIds, $newIds) as $company_id) {
            $this->remove($company_id);
        }

        return true;
    }
}
