<?php

namespace common\services;

use common\entities\Dictionaries\ConsumptionRatesMaterial;
use common\entities\Dictionaries\WorkList;
use common\entities\Dictionaries\WorkListsMaterial;
use common\repositories\WorkListsMaterialRepository;

class WorkListMaterialService
{
    private WorkListsMaterialRepository $workListsMaterial;

    public function __construct(WorkListsMaterialRepository $material)
    {
        $this->workListsMaterial = $material;
    }

    /**
     * Создание записи.
     */
    public function create($name, $unit_measure_id, $work_list_id, $sort): WorkListsMaterial
    {
        $material = new WorkListsMaterial();
        $material->create($name, $unit_measure_id, $work_list_id, $sort);
        $this->workListsMaterial->save($material);

        if ($consumptionRates = $material->consumptionRates) {
            foreach ($consumptionRates as $consumptionRate) {
                $consumptionRateMaterial = new ConsumptionRatesMaterial();
                $consumptionRateMaterial->create($consumptionRate->id, $material->id);
                $consumptionRateMaterial->save();
            }
        }

        return $material;
    }

    /**
     * Редактирование записи.
     */
    public function edit(int $id, $name, $unit_measure_id, $work_list_id, $sort): WorkListsMaterial
    {
        $material = $this->workListsMaterial->get($id);
        $material->create($name, $unit_measure_id, $work_list_id, $sort);
        $this->workListsMaterial->save($material);

        return $material;
    }

    /**
     * Удаление записи.
     */
    public function remove($id): void
    {
        $material = $this->workListsMaterial->get($id);
        $this->workListsMaterial->remove($material);
    }

    /**
     * Пакетное обновление записей материлов к работе.
     * @param array<array<string>> $materials
     */
    public function batchUpdate(array $materials, WorkList $workList): bool
    {
        $oldIds = [];
        $newIds = [];

        foreach ($workList->workListsMaterials as $oldMaterial) {
            $oldIds[] = $oldMaterial->id;
        }

        if (empty($materials) && empty($oldIds)) {
            return false;
        }

        $sort = 1;
        foreach ($materials as $material) {
            if (array_key_exists('id', $material) && in_array($material['id'], $oldIds)) {
                $item = $this->edit($material['id'], $material['name'], $material['unit_measure_id'], $workList->id, $sort);
            } else {
                $item = $this->create($material['name'], $material['unit_measure_id'], $workList->id, $sort);
            }
            $newIds[] = $item->id;
            $sort++;
        }

        foreach (array_diff($oldIds, $newIds) as $material_id) {
            $this->remove($material_id);
        }

        return true;
    }
}
