<?php

namespace common\tests\unit\entities\Company;

use Codeception\Test\Unit;
use common\forms\Company\CompanyForm;

class CompanyTest extends Unit
{
    /** @return array */
    public function fieldSuccessValues(): array
    {
        return [
            'full_name' => ['full_name', 'ООО Стройка века'],
            'short_name' => ['short_name', 'Стройка'],
            'delegate_name' => ['delegate_name', 'Иванов Иван Иванович'],
            'delegate_phones' => ['delegate_phones', ['+7 (904) 142-21-01', '+7 (495) 101-01-01']],
            'delegate_email' => ['delegate_email', 'email@mail.com'],
            'signer_post' => ['signer_post','Директор'],
            'signer_name' => ['signer_name', 'Петров Пётр Петрович'],
            'general_phones' => ['general_phones', ['+7 (495) 101-01-01']],
            'general_email' => ['general_email', 'email@mail.com'],
            'legal_adress' => ['legal_adress', 'Москва, ул. Строителей, д.3'],
            'physical_adress' => ['physical_adress', 'Москва, ул. Строителей, д.3'],
            'company_type' => ['company_type', '20'],
            'inn' => ['inn', '1234567890'],
            'ogrn' => ['ogrn', '1234567890123'],
            'okpo' => ['okpo', '12345678'],
            'kpp' => ['kpp', '123456789'],
            'company_url' => ['company_url', 'https://site.com'],
            'payment_account' => ['payment_account','12345678901234567890'],
            'bank' => ['bank', 'Сбербанк'],
            'bank_cor_account' => ['bank_cor_account', '12345678901234567890'],
            'bank_bic' => ['bank_bic', '123456789'],
            'is_client' => ['is_client', '0'],
            'created_at' => ['created_at', '1392559490'],
            'updated_at' => ['updated_at', '1392559490'],
        ];
    }

    /** @return array */
    public function fieldBadValues(): array
    {
        return [
            'full_name' => ['full_name', ''],
            'short_name' => ['short_name', ''],
            'delegate_name' => ['delegate_name', ''],
            'delegate_phones' => ['delegate_phones', ['101-03-12']],
            'delegate_email' => ['delegate_email', 'email'],
            'signer_post' => ['signer_post',''],
            'signer_name' => ['signer_name', ''],
            'general_phones' => ['general_phones', ['495 101-01-01']],
            'general_email' => ['general_email', 'test'],
            'legal_adress' => ['legal_adress', ''],
            'physical_adress' => ['physical_adress', ''],
            'company_type' => ['company_type', 'test'],
            'inn' => ['inn', '123456789023525'],
            'ogrn' => ['ogrn', '123456789012323532'],
            'okpo' => ['okpo', '12345678235235'],
            'kpp' => ['kpp', '12345678923525'],
            'company_url' => ['company_url', 'site'],
            'payment_account' => ['payment_account','123456789012345678906346'],
            'bank' => ['bank', ''],
            'bank_cor_account' => ['bank_cor_account', '12345678901234567890346'],
            'bank_bic' => ['bank_bic', '1234567894636'],
            'is_client' => ['is_client', 'test'],
            'created_at' => ['created_at', 'test'],
            'updated_at' => ['updated_at', 'test'],
        ];
    }

    /** @dataProvider fieldSuccessValues */
    public function testSuccessValidation($field, $value)
    {
        $company = new CompanyForm();
        $company->$field = $value;
        $this->assertTrue($company->validate([$field]));
    }

    /** @dataProvider fieldBadValues */
    public function testBadValidation($field, $value)
    {
        $company = new CompanyForm();
        $company->$field = $value;
        $this->assertFalse($company->validate([$field]));
    }
}
