<?php

namespace common\tests\unit\Dictionaries;

use Codeception\Test\Unit;
use common\entities\Dictionaries\ConsumptionRate;
use common\fixtures\ConsumptionRateFixture;
use common\fixtures\ConsumptionRatesMaterialFixture;
use common\fixtures\UnitMeasureFixture;
use common\fixtures\WorkListFixture;
use common\fixtures\WorkListsMaterialFixture;
use common\repositories\ConsumptionRatesMaterialRepository;
use common\services\ConsumptionRatesMaterialService;
use common\tests\UnitTester;

class ConsumptionRateTest extends Unit
{
    protected UnitTester $tester;

    public function _before()
    {
        $this->tester->haveFixtures([
            'consumptionRate' => [
                'class' => ConsumptionRateFixture::class,
                'dataFile' => codecept_data_dir() . 'consumption_rate.php',
            ],
            'unitMeasure' => [
                'class' => UnitMeasureFixture::class,
                'dataFile' => codecept_data_dir() . 'unit_measure.php',
            ],
            'workList' => [
                'class' => WorkListFixture::class,
                'dataFile' => codecept_data_dir() . 'work_list.php',
            ],
            'workListsMaterial' => [
                'class' => WorkListsMaterialFixture::class,
                'dataFile' => codecept_data_dir() . 'work_lists_material.php',
            ],
            'consumptionRatesMaterial' => [
                'class' => ConsumptionRatesMaterialFixture::class,
                'dataFile' => codecept_data_dir() . 'consumption_rates_material.php',
            ],
        ]);
    }

    /** @return array */
    public function fieldSuccessValues(): array
    {
        return [
            'work_list_id' => ['work_list_id', '1'],
            'work_scope' => ['work_scope', '42'],
            'work_unit_cost' => ['work_unit_cost', '6874.904'],
            'created_at' => ['created_at', time()],
            'updated_at' => ['updated_at', time()],
        ];
    }

    /** @return array */
    public function fieldBadValues(): array
    {
        return [
            'work_list_id' => ['work_list_id', 'test'],
            'work_scope' => ['work_scope', 'test'],
            'work_unit_cost' => ['work_unit_cost', 'test'],
            'created_at' => ['created_at', 'test'],
            'updated_at' => ['updated_at', 'test'],
        ];
    }

    /** @return array */
    public function fields(): array
    {
        return [
            'id' => 2,
            'work_list_id' => 1,
            'work_scope' => 42,
            'work_unit_cost' => 6874.90,
        ];
    }

    /** @return array */
    public function materials(): array
    {
        return [
            [
                'id' => 1,
                'consumption_rate_id' => 1,
                'material_id' => 1,
                'material_expense' => 100,
                'material_unit_cost' => 100,
            ],
            [
                'id' => 2,
                'consumption_rate_id' => 1,
                'material_id' => 2,
                'material_expense' => 200,
                'material_unit_cost' => 200,
            ],
        ];
    }

    /** @dataProvider fieldSuccessValues */
    public function testSuccessValidation($field, $value)
    {
        $item = new ConsumptionRate();
        $item->$field = $value;
        $this->assertTrue($item->validate([$field]));
    }

    /** @dataProvider fieldBadValues */
    public function testBadValidation($field, $value)
    {
        $item = new ConsumptionRate();
        $item->$field = $value;
        $this->assertFalse($item->validate([$field]));
    }

    public function testSave()
    {
        $model = new ConsumptionRate($this->fields());

        expect_that($model->save());
    }

    public function testNotSave()
    {
        $model = new ConsumptionRate([
            'work_list_id' => '1',
            'work_scope' => 'test',
        ]);

        expect_not($model->save());
    }

    public function testDelete()
    {
        $model = new ConsumptionRate($this->fields());
        $model->save();

        expect_that($model->delete());
    }

    public function testMaterialsSave()
    {
        $service = new ConsumptionRatesMaterialService(new ConsumptionRatesMaterialRepository());

        expect_that($service->batchUpdate($this->materials()));
    }
}
