<?php

namespace common\tests\unit\Dictionaries;

use Codeception\Test\Unit;
use common\entities\Dictionaries\UnitMeasure;
use common\tests\UnitTester;

class UnitMeasureTest extends Unit
{
    protected UnitTester $tester;

    /** @return array */
    public function fieldSuccessValues(): array
    {
        return [
            'name' => ['name', 'Квадратный метр'],
            'alias' => ['alias', 'м2'],
            'created_at' => ['created_at', '1392559490'],
            'updated_at' => ['updated_at', '1392559490'],
        ];
    }

    /** @return array */
    public function fieldBadValues(): array
    {
        return [
            'name' => ['name', ''],
            'alias' => ['alias', ''],
            'created_at' => ['created_at', 'test'],
            'updated_at' => ['updated_at', 'test'],
        ];
    }

    /** @dataProvider fieldSuccessValues */
    public function testSuccessValidation($field, $value)
    {
        $company = new UnitMeasure();
        $company->$field = $value;
        $this->assertTrue($company->validate([$field]));
    }

    /** @dataProvider fieldBadValues */
    public function testBadValidation($field, $value)
    {
        $company = new UnitMeasure();
        $company->$field = $value;
        $this->assertFalse($company->validate([$field]));
    }

    public function testSave()
    {
        $model = new UnitMeasure([
            'name' => 'Кубический метр',
            'alias' => 'м3',
        ]);

        expect_that($model->save());
    }

    public function testNotSave()
    {
        $model = new UnitMeasure([
            'name' => 'Кубический метр',
            'alias' => '',
        ]);

        expect_not($model->save());
    }

    public function testDelete()
    {
        $model = new UnitMeasure([
            'name' => 'Кубический метр',
            'alias' => 'м3',
        ]);
        $model->save();

        expect_that($model->delete());
    }
}
