<?php

namespace common\tests\unit\Dictionaries;

use Codeception\Test\Unit;
use common\entities\Dictionaries\WorkList;
use common\fixtures\UnitMeasureFixture;
use common\fixtures\WorkListFixture;
use common\fixtures\WorkTypeFixture;
use common\repositories\WorkListsMaterialRepository;
use common\services\WorkListMaterialService;
use common\tests\UnitTester;

class WorkListTest extends Unit
{
    protected UnitTester $tester;

    public function _before()
    {
        $this->tester->haveFixtures([
            'workType' => [
                'class' => WorkTypeFixture::class,
                'dataFile' => codecept_data_dir() . 'work_type.php',
            ],
            'unitMeasure' => [
                'class' => UnitMeasureFixture::class,
                'dataFile' => codecept_data_dir() . 'unit_measure.php',
            ],
            'workList' => [
                'class' => WorkListFixture::class,
                'dataFile' => codecept_data_dir() . 'work_list.php',
            ],
        ]);
    }

    /** @return array */
    public function fieldSuccessValues(): array
    {
        return [
            'name' => ['name', 'покраска подготовленной деревянной перегородки'],
            'alias' => ['alias', 'покраска перегородки'],
            'description' => ['description', 'Описание'],
            'work_type_id' => ['work_type_id', '1'],
            'unit_measure_id' => ['unit_measure_id', '1'],
            'created_at' => ['created_at', time()],
            'updated_at' => ['updated_at', time()],
        ];
    }

    /** @return array */
    public function fieldBadValues(): array
    {
        return [
            'name' => ['name', ''],
            'alias' => ['alias', ''],
            'created_at' => ['created_at', 'test'],
            'updated_at' => ['updated_at', 'test'],
        ];
    }

    /** @return array */
    public function fields(): array
    {
        return [
            'name' => 'покраска подготовленной деревянной перегородки',
            'alias' => 'покраска перегородки',
            'description' => 'Описание',
            'work_type_id' => '1',
            'unit_measure_id' => '1',
        ];
    }

    /** @return array */
    public function materials(): array
    {
        return [
            [
                'work_list_id' => '2',
                'name' => 'краска',
                'unit_measure_id' => '1',
            ],
            [
                'work_list_id' => '2',
                'name' => 'кисточка',
                'unit_measure_id' => '1',
            ],
        ];
    }

    /** @dataProvider fieldSuccessValues */
    public function testSuccessValidation($field, $value)
    {
        $item = new WorkList();
        $item->$field = $value;
        $this->assertTrue($item->validate([$field]));
    }

    /** @dataProvider fieldBadValues */
    public function testBadValidation($field, $value)
    {
        $item = new WorkList();
        $item->$field = $value;
        $this->assertFalse($item->validate([$field]));
    }

    public function testSave()
    {
        $model = new WorkList($this->fields());

        expect_that($model->save());
    }

    public function testNotSave()
    {
        $model = new WorkList([
            'name' => '',
        ]);

        expect_not($model->save());
    }

    public function testDelete()
    {
        $model = new WorkList($this->fields());
        $model->save();

        expect_that($model->delete());
    }

    public function testMaterialsSave()
    {
        $service = new WorkListMaterialService(new WorkListsMaterialRepository());
        $model = new WorkList($this->fields());
        $model->save();

        expect_that($service->batchUpdate($this->materials(), $model));
    }
}
