<?php

namespace common\tests\unit\Dictionaries;

use Codeception\Test\Unit;
use common\entities\Dictionaries\WorkType;
use common\tests\UnitTester;

class WorkTypeTest extends Unit
{
    protected UnitTester $tester;

    /** @return array */
    public function fieldSuccessValues(): array
    {
        return [
            'name' => ['name', 'Геодезические'],
            'alias' => ['alias', 'ГДЗ'],
            'description' => ['description', 'Описание'],
            'created_at' => ['created_at', '1392559490'],
            'updated_at' => ['updated_at', '1392559490'],
        ];
    }

    /** @return array */
    public function fieldBadValues(): array
    {
        return [
            'name' => ['name', ''],
            'alias' => ['alias', '1234567'],
            'created_at' => ['created_at', 'test'],
            'updated_at' => ['updated_at', 'test'],
        ];
    }

    /** @dataProvider fieldSuccessValues */
    public function testSuccessValidation($field, $value)
    {
        $item = new WorkType();
        $item->$field = $value;
        $this->assertTrue($item->validate([$field]));
    }

    /** @dataProvider fieldBadValues */
    public function testBadValidation($field, $value)
    {
        $item = new WorkType();
        $item->$field = $value;
        $this->assertFalse($item->validate([$field]));
    }

    public function testSave()
    {
        $model = new WorkType([
            'name' => 'Каменные',
            'description' => 'Описание',
            'alias' => 'КМ',
        ]);

        expect_that($model->save());
    }

    public function testNotSave()
    {
        $model = new WorkType([
            'name' => '',
            'alias' => 'Каменные',
        ]);

        expect_not($model->save());
    }

    public function testDelete()
    {
        $model = new WorkType([
            'name' => 'Каменные',
            'description' => 'Описание',
            'alias' => 'КМ',
        ]);
        $model->save();

        expect_that($model->delete());
    }
}
