<?php

namespace common\tests\unit\forms;

use Codeception\Test\Unit;
use common\entities\Company\Company;
use common\fixtures\CompanyFixture;
use common\tests\UnitTester;

/**
 * Тест модели юридические лица.
 */
class CompanyFormTest extends Unit
{
    protected UnitTester $tester;

    public function _before()
    {
        $this->tester->haveFixtures([
            'company' => [
                'class' => CompanyFixture::class,
                'dataFile' => codecept_data_dir() . 'company.php',
            ],
        ]);
    }

    public function testBlank()
    {
        $model = new Company([
            'full_name' => '',
            'short_name' => '',
        ]);

        expect_not($model->validate());
        expect_not($model->save());
    }

    public function testSave()
    {
        $model = new Company();

        $model->full_name = 'ООО Стройка века';
        $model->short_name = 'Стройка';
        $model->delegate_name = 'Иванов Иван Иванович';
        $model->delegate_phones = ['+7 (904) 101-01-01', '+7 (904) 352-34-34'];
        $model->delegate_email = 'email@mail.com';
        $model->signer_post = 'Директор';
        $model->signer_name = 'Петров Пётр Петрович';
        $model->general_phones = ['+7 (495) 101-01-01'];
        $model->general_email = 'email@mail.com';
        $model->legal_adress = 'Москва, ул. Строителей, д.3';
        $model->physical_adress = 'Москва, ул. Строителей, д.3';
        $model->company_type = '20';
        $model->inn = '4583484438';
        $model->ogrn = '5236374576890';
        $model->okpo = '34634747';
        $model->kpp = '569537547';
        $model->company_url = 'https://site.com';
        $model->payment_account = '33723475672372372347';
        $model->bank = 'Сбербанк';
        $model->bank_cor_account = '34723745782723473472';
        $model->bank_bic = '457845845';
        $model->is_client = '1';

        expect_that($model->save());
    }

    public function testUnique()
    {
        $model = new Company();

        $model->inn = '1234567890';
        $model->ogrn = '5236374576890';
        $model->payment_account = '33723475672372372347';

        expect_not($model->validate());
    }
}
