<?php

namespace common\tests\unit\forms;

use Codeception\Test\Unit;
use common\forms\auth\PasswordResetRequestForm;
use common\fixtures\UserFixture;
use common\entities\User\User;
use common\tests\UnitTester;

class PasswordResetRequestFormTest extends Unit
{
    protected UnitTester $tester;

    public function _before()
    {
        $this->tester->haveFixtures([
            'user' => [
                'class' => UserFixture::className(),
                'dataFile' => codecept_data_dir() . 'user.php',
            ],
        ]);
    }

    public function testWithWrongEmailAddress()
    {
        $model = new PasswordResetRequestForm();
        $model->email = 'not-existing-email@example.com';
        expect_not($model->validate());
    }

    public function testInactiveUser()
    {
        $user = $this->tester->grabFixture('user', 1);
        $model = new PasswordResetRequestForm();
        $model->email = $user['email'];
        expect_not($model->validate());
    }

    public function testSuccessfully()
    {
        $userFixture = $this->tester->grabFixture('user', 0);
        
        $model = new PasswordResetRequestForm();
        $model->email = $userFixture['email'];
        expect_that(User::findOne(['password_reset_token' => $userFixture['password_reset_token']]));
        expect_that($model->validate());
    }
}
