<?php

namespace common\tests\unit\modules;

use common\tests\unit\modules\fixtures\PostFixture;
use PHPUnit_Framework_TestCase;
use yii\base\InvalidConfigException;
use yii\console\controllers\MigrateController;
use yii\di\Container;
use yii\helpers\ArrayHelper;
use Yii;
use yii\web\Application;

abstract class TestCase extends PHPUnit_Framework_TestCase
{
    private static bool $migrationApplied = false;

    /** @throws InvalidConfigException */
    protected function setUp(): void
    {
        $this->mockApplication();
        $this->applyMigrations();
        $this->applyFixtures();
        $this->clearHistory();
    }

    protected function tearDown(): void
    {
        $this->destroyApplication();
    }

    private function applyMigrations()
    {
        if (!self::$migrationApplied) {
            $migrateController = new MigrateController('migrate', Yii::$app);
            $migrateController->interactive = false;
            $migrateController->migrationPath = [
                'common/tests/unit/modules/migrations',
            ];
            $migrateController->runAction('up');

            self::$migrationApplied = true;
        }
    }

    /**
     * @param array<string> $config
     * @throws InvalidConfigException
     */
    private function mockApplication($config = [])
    {
        new Application(ArrayHelper::merge(require __DIR__ . '/config/main.php', $config));
    }

    /**
     * Destroys application in Yii::$app by setting it to null.
     */
    private function destroyApplication()
    {
        Yii::$app = null;
        Yii::$container = new Container();
    }

    private function applyFixtures()
    {
        $postFixture = new PostFixture();

        $postFixture->unload();
        $postFixture->load();
    }

    private function clearHistory()
    {
        Yii::$app->db->createCommand('TRUNCATE `model_histories`')->execute();
    }
}
