<?php

namespace console\components\db;

use Yii;

/**
 * Трейт сброса счетчиков автоинкремента в БД.
 */
trait ResetIncrements
{
    /**
     * Сброс счетчика автоинкремента во всех таблицах.
     *
     * @throws \yii\base\NotSupportedException
     */
    private function resetAllIncrements(): void
    {
        $db = Yii::$app->getDb();

        if ($db->driverName !== 'mysql') {
            return ;
        }

        foreach($db->getSchema()->getTableSchemas() as $item) {
            $table = $item->name;
            $sequenceName = $item->sequenceName;

            if ($sequenceName) {
                $this->resetIncrementInTable($table, $sequenceName);
            }
        }
    }

    /**
     * Сброс счетчика автоинкремента в заданной таблице.
     *
     * @param string $table название таблицы
     * @param string $seqName название счетчика
     */
    private function resetIncrementInTable(string $table, string $seqName): void
    {
        $db = Yii::$app->getDb();

        try {
            $max = $db->createCommand("SELECT MAX(id) FROM {$table}")->queryScalar() + 1;
            $db->createCommand("ALTER SEQUENCE {$seqName} RESTART WITH {$max}")
                ->execute();
        } catch (\yii\db\Exception $e) {

        }
    }
}