<?php

namespace console\controllers;

use common\entities\User\User;
use console\components\db\ResetIncrements;
use yii\console\Controller;
use yii\console\ExitCode;

/**
 * Контроллер консольных команд для приложения.
 */
class AppController extends Controller
{
    use ResetIncrements;

    /**
     * Инициализация минимально необходимых данных.
     *
     * @return int
     * @throws \yii\base\Exception
     */
    public function actionInit(): int
    {
        $this->createDefaultAdmin();
        $this->resetAllIncrements();

        return ExitCode::OK;
    }

    /**
     * Восстановление счётчеков первичных ключей для таблиц базы данных.
     *
     * @return int
     * @throws \yii\base\NotSupportedException
     */
    public function actionResetPkSeq(): int
    {
        $this->resetAllIncrements();

        return ExitCode::OK;
    }

    /**
     * Создание учетной записи администратора по-умолчанию.
     *
     * @throws \yii\base\Exception
     */
    private function createDefaultAdmin(): void
    {
        if (User::find()->where(['username' => 'admin'])->exists()) {
            return;
        }

        $user = new User([
            'username' => 'admin',
            'email' => 'admin@example.com',
            'password' => '123456',
        ]);
        $user->generateAuthKey();
        $user->generatePasswordResetToken();
        $user->generateEmailVerificationToken();
        $user->save(false);
    }
}
