<?php

use yii\db\Migration;

/**
 * Миграция добавляет таблицу юридические лица.
 */
class m210618_083845_create_company_table extends Migration
{
    private const TABLE_NAME = '{{%companies}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey()->unsigned(),
            'full_name' => $this->string(255)->notNull()->comment('Полное наименование'),
            'short_name' => $this->string(255)->notNull()->comment('Короткое наименование'),
            'delegate_name' => $this->string(255)->notNull()->comment('ФИО представителя'),
            'delegate_phones' => $this->text()->notNull()->comment('Контактные телефоны представителя'),
            'delegate_email' => $this->string(255)->notNull()->comment('Почта представителя'),
            'signer_post' => $this->string(255)->notNull()->comment('Должность подписанта'),
            'signer_name' => $this->string(255)->notNull()->comment('ФИО подписанта'),
            'general_phones' => $this->text()->null()->comment('Общие телефоны компании'),
            'general_email' => $this->string(255)->null()->comment('Общая почта'),
            'legal_adress' => $this->string(255)->notNull()->comment('Юридический адрес'),
            'physical_adress' => $this->string(255)->notNull()->comment('Фактический адрес'),
            'company_type' => $this->tinyInteger(2)->notNull()->comment('Тип организации'),
            'inn' => $this->string(10)->notNull()->unique()->comment('ИНН'),
            'ogrn' => $this->string(13)->notNull()->unique()->comment('ОГРН'),
            'okpo' => $this->string(10)->notNull()->comment('ОКПО'),
            'kpp' => $this->string(9)->notNull()->unique()->comment('КПП'),
            'company_url' => $this->string(255)->null()->comment('Ссылка на сайт'),
            'payment_account' => $this->string(20)->notNull()->unique()->comment('Р/С'),
            'bank' => $this->string(255)->notNull()->comment('Банк'),
            'bank_cor_account' => $this->string(20)->notNull()->comment('К/С'),
            'bank_bic' => $this->string(9)->notNull()->comment('БИК'),
            'is_client' => $this->boolean()->notNull()->defaultValue(false)->comment('Является клиентом'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Юридические лица');
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropTable(self::TABLE_NAME);
    }
}
