<?php

use yii\db\Migration;

/**
 * Добавление таблицы с перечнями работ.
 */
class m210624_071032_create_work_lists_table extends Migration
{
    private const TABLE_NAME = '{{%work_lists}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey(11)->unsigned(),
            'name' => $this->string(255)->notNull()->comment('Наименование работы'),
            'alias' => $this->string(128)->notNull()->comment('Сокращенное наименование'),
            'description' => $this->string(512)->notNull()->comment('Описание'),
            'work_type_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись типа работы'),
            'unit_measure_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись единицы измерения'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Перечень работ');

        $this->addForeignKey(
            'FK1_work_lists_unit_measure_id',
            self::TABLE_NAME,
            'unit_measure_id',
            '{{%unit_measures}}',
            'id',
        );

        $this->addForeignKey(
            'FK2_work_lists_work_type_id',
            self::TABLE_NAME,
            'work_type_id',
            '{{%work_types}}',
            'id',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_work_lists_unit_measure_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_work_lists_work_type_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
