<?php

use yii\db\Migration;

/**
 * Добавление таблицы для связки перечня работ и материалов.
 */
class m210625_083625_create_work_lists_materials_table extends Migration
{
    private const TABLE_NAME = '{{%work_lists_materials}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey()->unsigned(),
            'work_list_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись работы'),
            'name' => $this->string(255)->notNull()->comment('Наименование материала'),
            'unit_measure_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись единицы измерения'),
            'sort' => $this->integer(11)->unsigned()->defaultValue(1)->notNull()->comment('Сортировка'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Материалы перечня работ');

        $this->addForeignKey(
            'FK1_work_lists_materials_unit_measure_id',
            self::TABLE_NAME,
            'unit_measure_id',
            '{{%unit_measures}}',
            'id',
        );

        $this->addForeignKey(
            'FK2_work_lists_materials_work_list_id',
            self::TABLE_NAME,
            'work_list_id',
            '{{%work_lists}}',
            'id',
            'CASCADE',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_work_lists_materials_unit_measure_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_work_lists_materials_work_list_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
