<?php

use yii\db\Migration;

/**
 * Добавление таблицы для связки нормы расходов и материалов.
 */
class m210625_083832_create_consumption_rates_materials_table extends Migration
{
    private const TABLE_NAME = '{{%consumption_rates_materials}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey()->unsigned(),
            'consumption_rate_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись нормы расхода'),
            'material_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись материала'),
            'material_expense' => $this->decimal(10, 2)->unsigned()->comment('Расход материала'),
            'material_unit_cost' => $this->decimal(10, 2)->unsigned()->comment('Стоимость за единицу материала'),
            'sort' => $this->integer(11)->unsigned()->defaultValue(1)->notNull()->comment('Сортировка'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Материалы норм расходов');

        $this->addForeignKey(
            'FK1_consumption_rates_materials_consumption_rate_id',
            self::TABLE_NAME,
            'consumption_rate_id',
            '{{%consumption_rates}}',
            'id',
            'CASCADE',
        );
        $this->addForeignKey(
            'FK2_consumption_rates_materials_material_id',
            self::TABLE_NAME,
            'material_id',
            '{{%work_lists_materials}}',
            'id',
            'CASCADE',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_consumption_rates_materials_consumption_rate_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_consumption_rates_materials_material_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
