<?php

use yii\db\Migration;

/**
 * Handles the creation of table `{{%contracts}}`.
 */
class m210630_083936_create_contracts_table extends Migration
{
    private const TABLE_NAME = '{{%contracts}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey(11)->unsigned(),
            'company_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись юридического лица'),
            'number' => $this->string(255)->notNull()->unique()->comment('Номер договора'),
            'date_start' => $this->date()->notNull()->comment('Дата договора'),
            'subject_address' => $this->string(512)->null()->comment('Адрес объекта'),
            'subject_name' => $this->string(255)->null()->comment('Наименование объекта'),
            'is_act_counter_increase_annually' => $this->boolean()
                ->notNull()->defaultValue(0)->comment('Обновление счетчика акта после нг'),
            'documents_day_end' => $this->tinyInteger(2)->notNull()->comment('Число закрытия документов'),
            'status' => $this->tinyInteger(2)->notNull()->defaultValue(30)->comment('Статус'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Договоры');

        $this->addForeignKey(
            'FK1_contracts_company_id',
            self::TABLE_NAME,
            'company_id',
            '{{%companies}}',
            'id',
            'CASCADE',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_contracts_company_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
