<?php

use yii\db\Migration;

/**
 * Handles the creation of table `{{%contract_expenses}}`.
 */
class m210701_125731_create_contract_expenses_table extends Migration
{
    private const TABLE_NAME = '{{%contract_expenses}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey(11)->unsigned(),
            'contract_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись договора'),
            'expense_type' => $this->tinyInteger(2)->notNull()->comment('Тип расхода'),
            'amount' => $this->decimal(10, 2)->unsigned()->notNull()->comment('Сумма'),
            'is_nds' => $this->boolean()->notNull()->defaultValue(0)->comment('НДС'),
            'contractor_id' => $this->integer(11)->unsigned()->null()->comment('Ответственный за покупку'),
            'comment' => $this->string(512)->notNull()->comment('Дополнительный комментарий'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Связанные расходы по договору');

        $this->addForeignKey(
            'FK1_contract_expenses_contract_id',
            self::TABLE_NAME,
            'contract_id',
            '{{%contracts}}',
            'id',
            'CASCADE',
        );
        $this->addForeignKey(
            'FK2_contract_expenses_contractor_id',
            self::TABLE_NAME,
            'contractor_id',
            '{{%contract_companies}}',
            'company_id',
            'SET NULL',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_contract_expenses_contract_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_contract_expenses_contractor_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
