<?php

use yii\db\Migration;

/**
 * Handles the creation of table `{{%contract_estimates}}`.
 */
class m210712_070932_create_contract_estimates_table extends Migration
{
    private const TABLE_NAME = '{{%contract_estimates}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey(11)->unsigned(),
            'contract_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись договора'),
            'work_type_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись типа работы'),
            'surface' => $this->tinyInteger(2)->notNull()->comment('Поверхность'),
            'bill_number' => $this->string(255)->notNull()->comment('Номер счета/накладной'),
            'bill_date' => $this->date()->null()->comment('Дата счета/накладной'),
            'work_list_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись работы'),
            'type' => $this->tinyInteger(2)->notNull()->comment('Тип работы'),
            'contractor_id' => $this->integer(11)->unsigned()->notNull()->comment('Ответственный за исполнение'),
            'quantity' => $this->decimal(10, 2)->unsigned()->notNull()->comment('Количество'),
            'price_per_unit' => $this->decimal(10, 2)->unsigned()->notNull()->comment('Цена за единицу'),
            'markup' => $this->smallInteger(3)->unsigned()->defaultValue(0)->comment('Наценка'),
            'created_at' => $this->integer(11)->notNull()->comment('Дата создания'),
            'updated_at' => $this->integer(11)->notNull()->comment('Дата обновления'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Сметы к договору');

        $this->addForeignKey(
            'FK1_contract_estimates_contract_id',
            self::TABLE_NAME,
            'contract_id',
            '{{%contracts}}',
            'id',
            'CASCADE',
        );
        $this->addForeignKey(
            'FK2_contract_estimates_work_type_id',
            self::TABLE_NAME,
            'work_type_id',
            '{{%work_types}}',
            'id',
        );
        $this->addForeignKey(
            'FK3_contract_estimates_work_list_id',
            self::TABLE_NAME,
            'work_list_id',
            '{{%work_lists}}',
            'id',
        );
        $this->addForeignKey(
            'FK4_contract_estimates_contractor_id',
            self::TABLE_NAME,
            'contractor_id',
            '{{%contract_companies}}',
            'company_id',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_contract_estimates_contract_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_contract_estimates_work_type_id', self::TABLE_NAME);
        $this->dropForeignKey('FK3_contract_estimates_work_list_id', self::TABLE_NAME);
        $this->dropForeignKey('FK4_contract_estimates_contractor_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
