<?php

use yii\db\Migration;

/**
 * Handles the creation of table `{{%figures}}`.
 */
class m210802_153319_create_figures_table extends Migration
{
    private const TABLE_NAME = '{{%figures}}';

    /**
     * {@inheritdoc}
     */
    public function safeUp()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_general_ci ENGINE=InnoDB';
        }

        $this->createTable(self::TABLE_NAME, [
            'id' => $this->primaryKey(11)->unsigned(),
            'image_id' => $this->integer(11)->unsigned()->notNull()->comment('Запись изображения'),
            'type' => $this->tinyInteger(2)->null()->comment('Тип фигуры'),
            'coordinates' => $this->json()->null()->comment('Координаты'),
            'title' => $this->string(255)->null()->comment('Наименование области'),
            'length' => $this->decimal(10, 2)->unsigned()->null()->comment('Длина'),
            'width' => $this->decimal(10, 2)->unsigned()->null()->comment('Ширина'),
            'area' => $this->decimal(10, 2)->unsigned()->null()->comment('Площадь'),
            'footage' => $this->decimal(10, 2)->unsigned()->null()->comment('Объем'),
            'work_list_id' => $this->integer()->unsigned()->null()->comment('Запись работы'),
            'consumption_rate_id' => $this->integer()->unsigned()->null()->comment('Запись нормы расхода'),
        ], $tableOptions);

        $this->addCommentOnTable(self::TABLE_NAME, 'Фигуры');

        $this->addForeignKey(
            'FK1_figures_image_id',
            self::TABLE_NAME,
            'image_id',
            '{{%project_images}}',
            'id',
            'CASCADE',
        );

        $this->addForeignKey(
            'FK2_figures_work_list_id',
            self::TABLE_NAME,
            'work_list_id',
            '{{%work_lists}}',
            'id',
        );

        $this->addForeignKey(
            'FK3_figures_consumption_rate_id',
            self::TABLE_NAME,
            'consumption_rate_id',
            '{{%consumption_rates}}',
            'id',
        );
    }

    /**
     * {@inheritdoc}
     */
    public function safeDown()
    {
        $this->dropForeignKey('FK1_figures_image_id', self::TABLE_NAME);
        $this->dropForeignKey('FK2_figures_work_list_id', self::TABLE_NAME);
        $this->dropForeignKey('FK3_figures_consumption_rate_id', self::TABLE_NAME);

        $this->dropTable(self::TABLE_NAME);
    }
}
