<?php

/**
 * @SWG\Get(
 *     path="/v1/consumption-rates/rates/{work_list_id}",
 *     summary="Список норм расходов",
 *     description="Возвращает массив норм расходов к работе",
 *     security={{"apiKey":{}}},
 *     tags={"Нормы расходов"},
 *     @SWG\Parameter(
 *         description="Id работы из перечня",
 *         in="path",
 *         name="work_list_id",
 *         required=true,
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(
 *                  @SWG\Property(property="id", type="integer"),
 *                  @SWG\Property(property="name", type="string"),
 *             )
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/consumption-rates/{consumption_rate_id}?expand=materials",
 *     summary="Норма расхода с материалами",
 *     description="Возвращает норму расхода по Id",
 *     security={{"apiKey":{}}},
 *     tags={"Нормы расходов"},
 *     @SWG\Parameter(
 *         description="Id нормы расхода",
 *         in="path",
 *         required=true,
 *         name="consumption_rate_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(
 *                  @SWG\Property(property="id", description="Id нормы расхода", type="integer"),
 *                  @SWG\Property(property="work", description="Наименование работы", type="string"),
 *                  @SWG\Property(property="work_scope",  description="Планируемый объем работ", type="number"),
 *                  @SWG\Property(property="work_unit_cost", description="Стоимость за единицу работы", type="number"),
 *                  @SWG\Property(property="materials_count", description="Количество материалов", type="integer"),
 *                  @SWG\Property(property="materials", type="array",
 *                      @SWG\Items(
 *                          @SWG\Property(property="id", type="integer"),
 *                          @SWG\Property(property="consumption_rate_id", type="integer"),
 *                          @SWG\Property(property="material", description="Количество материалов", type="string"),
 *                          @SWG\Property(property="material_expense", description="Расход материала", type="number"),
 *                          @SWG\Property(property="material_unit_cost", description="Стоимость за единицу материала", type="number"),
 *                      )
 *                  ),
 *             )
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/consumption-rates/duplicateRate/{consumption_rate_id}",
 *     summary="Создание новой нормы расхода",
 *     description="Создает дубль записи нормы расхода",
 *     security={{"apiKey":{}}},
 *     tags={"Нормы расходов"},
 *     @SWG\Parameter(
 *         description="Id нормы расхода",
 *         in="path",
 *         required=true,
 *         name="consumption_rate_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Post(
 *     path="/v1/consumption-rates/updateMaterials",
 *     summary="Массив материалов к обновлению",
 *     description="Обновляет материалы к норме расходов",
 *     security={{"apiKey":{}}},
 *     tags={"Нормы расходов"},
 *     @SWG\Parameter(
 *         description="Массив материалов",
 *         in="body",
 *         required=true,
 *         name="materials",
 *         type="array",
 *         @SWG\Schema(type="array", @SWG\Items(ref="#/definitions/ConsumptionRatesMaterial")),
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 */
