<?php

/**
 * @SWG\Get(
 *     path="/v1/project/{project_id}/images",
 *     summary="Изображения",
 *     description="Возвращает все изображения по типу работ",
 *     security={{"apiKey":{}}},
 *     tags={"Изображения"},
 *     @SWG\Parameter(
 *         description="Id проекта",
 *         in="path",
 *         required=true,
 *         name="project_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(
 *                  @SWG\Property(property="id", description="Id изображения", type="integer"),
 *                  @SWG\Property(property="path", description="Путь до изображения", type="string"),
 *             )
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/project/image/{image_id}",
 *     summary="Изображение",
 *     description="Возвращает одно изображение по Id",
 *     security={{"apiKey":{}}},
 *     tags={"Изображения"},
 *     @SWG\Parameter(
 *         description="Id проекта",
 *         in="path",
 *         required=true,
 *         name="project_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(
 *                  @SWG\Property(property="id", description="Id изображения", type="integer"),
 *                  @SWG\Property(property="path", description="Путь до изображения", type="string"),
 *                  @SWG\Property(property="workType", description="Тип работы", type="string"),
 *                  @SWG\Property(property="stage", description="Этаж", type="integer"),
 *             )
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/project/image/{image_id}/figures",
 *     summary="Список фигур",
 *     description="Возвращает список фигур, связанных с изображением",
 *     security={{"apiKey":{}}},
 *     tags={"Изображения"},
 *     @SWG\Parameter(
 *         description="Id изображения",
 *         in="path",
 *         required=true,
 *         name="image_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(ref="#/definitions/Figure")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/project/image/{image_id}/axes",
 *     summary="Список осей",
 *     description="Возвращает список осей, связанных с изображением",
 *     security={{"apiKey":{}}},
 *     tags={"Изображения"},
 *     @SWG\Parameter(
 *         description="Id изображения",
 *         in="path",
 *         required=true,
 *         name="image_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(ref="#/definitions/Axis")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 * @SWG\Get(
 *     path="/v1/project/{project_id}/estimates",
 *     summary="Список смет",
 *     description="Возвращает все сметы по типу работ и ответственному за исполнение",
 *     security={{"apiKey":{}}},
 *     tags={"Изображения"},
 *     @SWG\Parameter(
 *         description="Id проекта",
 *         in="path",
 *         required=true,
 *         name="project_id",
 *         type="integer",
 *         format="int64"
 *     ),
 *     @SWG\Response(
 *         response=200,
 *         description="Успешное выполнение",
 *         @SWG\Schema(
 *             type="array",
 *             @SWG\Items(ref="#/definitions/Estimate")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="403",
 *         description="Forbidden",
 *         @SWG\Schema(
 *             @SWG\Items(ref="#/definitions/HttpException403")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="404",
 *         description="not_found",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/HttpException404")
 *         ),
 *     ),
 *     @SWG\Response(
 *         response="500",
 *         description= "critical_error_thrown",
 *         @SWG\Schema(
 *                 @SWG\Items(ref="#/definitions/Exception")
 *         ),
 *     ),
 * ),
 */
